"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExternalHooks = void 0;
const _1 = require("./");
const config = require("../config");
class ExternalHooksClass {
    constructor() {
        this.externalHooks = {};
        this.initDidRun = false;
    }
    async init() {
        if (this.initDidRun === true) {
            return;
        }
        const externalHookFiles = config.get('externalHookFiles').split(':');
        for (let hookFilePath of externalHookFiles) {
            hookFilePath = hookFilePath.trim();
            if (hookFilePath !== '') {
                try {
                    const hookFile = require(hookFilePath);
                    for (const resource of Object.keys(hookFile)) {
                        for (const operation of Object.keys(hookFile[resource])) {
                            const hookString = `${resource}.${operation}`;
                            if (this.externalHooks[hookString] === undefined) {
                                this.externalHooks[hookString] = [];
                            }
                            this.externalHooks[hookString].push.apply(this.externalHooks[hookString], hookFile[resource][operation]);
                        }
                    }
                }
                catch (error) {
                    throw new Error(`Problem loading external hook file "${hookFilePath}": ${error.message}`);
                }
            }
        }
        this.initDidRun = true;
    }
    async run(hookName, hookParameters) {
        const externalHookFunctions = {
            dbCollections: _1.Db.collections,
        };
        if (this.externalHooks[hookName] === undefined) {
            return;
        }
        for (const externalHookFunction of this.externalHooks[hookName]) {
            await externalHookFunction.apply(externalHookFunctions, hookParameters);
        }
    }
    exists(hookName) {
        return !!this.externalHooks[hookName];
    }
}
let externalHooksInstance;
function ExternalHooks() {
    if (externalHooksInstance === undefined) {
        externalHooksInstance = new ExternalHooksClass();
    }
    return externalHooksInstance;
}
exports.ExternalHooks = ExternalHooks;
//# sourceMappingURL=ExternalHooks.js.map