"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getConfigValue = exports.getVersions = exports.getSessionId = exports.getBaseUrl = exports.logOutput = void 0;
const config = require("../config");
const path_1 = require("path");
const fs_1 = require("fs");
const util_1 = require("util");
const fsReadFileAsync = util_1.promisify(fs_1.readFile);
let versionCache;
function logOutput(message, level = 'log') {
    if (level === 'log') {
        console.log(message);
    }
    else if (level === 'error') {
        console.error(message);
    }
}
exports.logOutput = logOutput;
function getBaseUrl() {
    const protocol = config.get('protocol');
    const host = config.get('host');
    const port = config.get('port');
    const path = config.get('path');
    if (protocol === 'http' && port === 80 || protocol === 'https' && port === 443) {
        return `${protocol}://${host}${path}`;
    }
    return `${protocol}://${host}:${port}${path}`;
}
exports.getBaseUrl = getBaseUrl;
function getSessionId(req) {
    return req.headers.sessionid;
}
exports.getSessionId = getSessionId;
async function getVersions() {
    if (versionCache !== undefined) {
        return versionCache;
    }
    const packageFile = await fsReadFileAsync(path_1.join(__dirname, '../../package.json'), 'utf8');
    const packageData = JSON.parse(packageFile);
    versionCache = {
        cli: packageData.version,
    };
    return versionCache;
}
exports.getVersions = getVersions;
async function getConfigValue(configKey) {
    const configKeyParts = configKey.split('.');
    const configSchema = config.getSchema();
    let currentSchema = configSchema.properties;
    for (const key of configKeyParts) {
        if (currentSchema[key] === undefined) {
            throw new Error(`Key "${key}" of ConfigKey "${configKey}" does not exist`);
        }
        else if (currentSchema[key].properties === undefined) {
            currentSchema = currentSchema[key];
        }
        else {
            currentSchema = currentSchema[key].properties;
        }
    }
    if (currentSchema.env === undefined) {
        return config.get(configKey);
    }
    const fileEnvironmentVariable = process.env[currentSchema.env + '_FILE'];
    if (fileEnvironmentVariable === undefined) {
        return config.get(configKey);
    }
    let data;
    try {
        data = await fsReadFileAsync(fileEnvironmentVariable, 'utf8');
    }
    catch (error) {
        if (error.code === 'ENOENT') {
            throw new Error(`The file "${fileEnvironmentVariable}" could not be found.`);
        }
        throw error;
    }
    return data;
}
exports.getConfigValue = getConfigValue;
//# sourceMappingURL=GenericHelpers.js.map