"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getWorkflowHooksMain = exports.getWorkflowHooksIntegrated = exports.getBase = exports.executeWorkflow = exports.pushExecutionFinished = void 0;
const _1 = require("./");
const n8n_core_1 = require("n8n-core");
const n8n_workflow_1 = require("n8n-workflow");
const config = require("../config");
const typeorm_1 = require("typeorm");
function executeErrorWorkflow(workflowData, fullRunData, mode, executionId, retryOf) {
    let pastExecutionUrl = undefined;
    if (executionId !== undefined) {
        pastExecutionUrl = `${_1.WebhookHelpers.getWebhookBaseUrl()}execution/${executionId}`;
    }
    if (fullRunData.data.resultData.error !== undefined && workflowData.settings !== undefined && workflowData.settings.errorWorkflow) {
        const workflowErrorData = {
            execution: {
                id: executionId,
                url: pastExecutionUrl,
                error: fullRunData.data.resultData.error,
                lastNodeExecuted: fullRunData.data.resultData.lastNodeExecuted,
                mode,
                retryOf,
            },
            workflow: {
                id: workflowData.id !== undefined ? workflowData.id.toString() : undefined,
                name: workflowData.name,
            },
        };
        _1.WorkflowHelpers.executeErrorWorkflow(workflowData.settings.errorWorkflow, workflowErrorData);
    }
}
let throttling = false;
function pruneExecutionData() {
    if (!throttling) {
        throttling = true;
        const timeout = config.get('executions.pruneDataTimeout');
        const maxAge = config.get('executions.pruneDataMaxAge');
        const date = new Date();
        date.setHours(date.getHours() - maxAge);
        _1.Db.collections.Execution.delete({ stoppedAt: typeorm_1.LessThanOrEqual(date.toISOString()) })
            .then(data => setTimeout(() => {
            throttling = false;
        }, timeout * 1000)).catch(err => throttling = false);
    }
}
function pushExecutionFinished(mode, fullRunData, executionIdActive, executionIdDb, retryOf) {
    const pushRunData = Object.assign(Object.assign({}, fullRunData), { data: Object.assign(Object.assign({}, fullRunData.data), { resultData: Object.assign(Object.assign({}, fullRunData.data.resultData), { runData: {} }) }) });
    const sendData = {
        executionIdActive,
        executionIdDb,
        data: pushRunData,
        retryOf,
    };
    const pushInstance = _1.Push.getInstance();
    pushInstance.send('executionFinished', sendData);
}
exports.pushExecutionFinished = pushExecutionFinished;
function hookFunctionsPush() {
    return {
        nodeExecuteBefore: [
            async function (nodeName) {
                if (this.sessionId === undefined) {
                    return;
                }
                const pushInstance = _1.Push.getInstance();
                pushInstance.send('nodeExecuteBefore', {
                    executionId: this.executionId,
                    nodeName,
                }, this.sessionId);
            },
        ],
        nodeExecuteAfter: [
            async function (nodeName, data) {
                if (this.sessionId === undefined) {
                    return;
                }
                const pushInstance = _1.Push.getInstance();
                pushInstance.send('nodeExecuteAfter', {
                    executionId: this.executionId,
                    nodeName,
                    data,
                }, this.sessionId);
            },
        ],
        workflowExecuteBefore: [
            async function () {
                const pushInstance = _1.Push.getInstance();
                pushInstance.send('executionStarted', {
                    executionId: this.executionId,
                    mode: this.mode,
                    startedAt: new Date(),
                    retryOf: this.retryOf,
                    workflowId: this.workflowData.id,
                    workflowName: this.workflowData.name,
                });
            },
        ],
        workflowExecuteAfter: [
            async function (fullRunData, newStaticData) {
                pushExecutionFinished(this.mode, fullRunData, this.executionId, undefined, this.retryOf);
            },
        ],
    };
}
function hookFunctionsSave(parentProcessMode) {
    return {
        nodeExecuteBefore: [],
        nodeExecuteAfter: [],
        workflowExecuteBefore: [],
        workflowExecuteAfter: [
            async function (fullRunData, newStaticData) {
                if (config.get('executions.pruneData')) {
                    pruneExecutionData();
                }
                const isManualMode = [this.mode, parentProcessMode].includes('manual');
                try {
                    if (!isManualMode && _1.WorkflowHelpers.isWorkflowIdValid(this.workflowData.id) === true && newStaticData) {
                        try {
                            await _1.WorkflowHelpers.saveStaticDataById(this.workflowData.id, newStaticData);
                        }
                        catch (e) {
                            console.error(`There was a problem saving the workflow with id "${this.workflowData.id}" to save changed staticData: ${e.message}`);
                        }
                    }
                    let saveManualExecutions = config.get('executions.saveDataManualExecutions');
                    if (this.workflowData.settings !== undefined && this.workflowData.settings.saveManualExecutions !== undefined) {
                        saveManualExecutions = this.workflowData.settings.saveManualExecutions;
                    }
                    if (isManualMode && saveManualExecutions === false) {
                        return;
                    }
                    let saveDataErrorExecution = config.get('executions.saveDataOnError');
                    let saveDataSuccessExecution = config.get('executions.saveDataOnSuccess');
                    if (this.workflowData.settings !== undefined) {
                        saveDataErrorExecution = this.workflowData.settings.saveDataErrorExecution || saveDataErrorExecution;
                        saveDataSuccessExecution = this.workflowData.settings.saveDataSuccessExecution || saveDataSuccessExecution;
                    }
                    const workflowDidSucceed = !fullRunData.data.resultData.error;
                    if (workflowDidSucceed === true && saveDataSuccessExecution === 'none' ||
                        workflowDidSucceed === false && saveDataErrorExecution === 'none') {
                        if (!isManualMode) {
                            executeErrorWorkflow(this.workflowData, fullRunData, this.mode, undefined, this.retryOf);
                        }
                        return;
                    }
                    const fullExecutionData = {
                        data: fullRunData.data,
                        mode: fullRunData.mode,
                        finished: fullRunData.finished ? fullRunData.finished : false,
                        startedAt: fullRunData.startedAt,
                        stoppedAt: fullRunData.stoppedAt,
                        workflowData: this.workflowData,
                    };
                    if (this.retryOf !== undefined) {
                        fullExecutionData.retryOf = this.retryOf.toString();
                    }
                    if (this.workflowData.id !== undefined && _1.WorkflowHelpers.isWorkflowIdValid(this.workflowData.id.toString()) === true) {
                        fullExecutionData.workflowId = this.workflowData.id.toString();
                    }
                    const executionData = _1.ResponseHelper.flattenExecutionData(fullExecutionData);
                    const executionResult = await _1.Db.collections.Execution.save(executionData);
                    if (fullRunData.finished === true && this.retryOf !== undefined) {
                        await _1.Db.collections.Execution.update(this.retryOf, { retrySuccessId: executionResult.id });
                    }
                    if (!isManualMode) {
                        executeErrorWorkflow(this.workflowData, fullRunData, this.mode, executionResult ? executionResult.id : undefined, this.retryOf);
                    }
                }
                catch (error) {
                    if (!isManualMode) {
                        executeErrorWorkflow(this.workflowData, fullRunData, this.mode, undefined, this.retryOf);
                    }
                }
            },
        ],
    };
}
async function executeWorkflow(workflowInfo, additionalData, inputData) {
    const mode = 'integrated';
    if (workflowInfo.id === undefined && workflowInfo.code === undefined) {
        throw new Error(`No information about the workflow to execute found. Please provide either the "id" or "code"!`);
    }
    if (_1.Db.collections.Workflow === null) {
        await _1.Db.init();
    }
    let workflowData;
    if (workflowInfo.id !== undefined) {
        workflowData = await _1.Db.collections.Workflow.findOne(workflowInfo.id);
        if (workflowData === undefined) {
            throw new Error(`The workflow with the id "${workflowInfo.id}" does not exist.`);
        }
    }
    else {
        workflowData = workflowInfo.code;
    }
    const externalHooks = _1.ExternalHooks();
    await externalHooks.init();
    await externalHooks.run('workflow.execute', [workflowData, mode]);
    const nodeTypes = _1.NodeTypes();
    const workflowName = workflowData ? workflowData.name : undefined;
    const workflow = new n8n_workflow_1.Workflow({ id: workflowInfo.id, name: workflowName, nodes: workflowData.nodes, connections: workflowData.connections, active: workflowData.active, nodeTypes, staticData: workflowData.staticData });
    const executionId = '';
    const credentials = await _1.WorkflowCredentials(workflowData.nodes);
    const additionalDataIntegrated = await getBase(credentials);
    additionalDataIntegrated.hooks = getWorkflowHooksIntegrated(mode, executionId, workflowData, { parentProcessMode: additionalData.hooks.mode });
    const requiredNodeTypes = ['n8n-nodes-base.start'];
    let startNode;
    for (const node of workflowData.nodes) {
        if (requiredNodeTypes.includes(node.type)) {
            startNode = node;
            break;
        }
    }
    if (startNode === undefined) {
        throw new Error(`The workflow does not contain a "Start" node and can so not be executed.`);
    }
    inputData = inputData || [
        {
            json: {},
        },
    ];
    const nodeExecutionStack = [];
    nodeExecutionStack.push({
        node: startNode,
        data: {
            main: [inputData],
        },
    });
    const runExecutionData = {
        startData: {},
        resultData: {
            runData: {},
        },
        executionData: {
            contextData: {},
            nodeExecutionStack,
            waitingExecution: {},
        },
    };
    const workflowExecute = new n8n_core_1.WorkflowExecute(additionalDataIntegrated, mode, runExecutionData);
    const data = await workflowExecute.processRunExecutionData(workflow);
    await externalHooks.run('workflow.postExecute', [data, workflowData]);
    if (data.finished === true) {
        const returnData = _1.WorkflowHelpers.getDataLastExecutedNodeData(data);
        return returnData.data.main;
    }
    else {
        const error = new Error(data.data.resultData.error.message);
        error.stack = data.data.resultData.error.stack;
        throw error;
    }
}
exports.executeWorkflow = executeWorkflow;
async function getBase(credentials, currentNodeParameters) {
    const urlBaseWebhook = _1.WebhookHelpers.getWebhookBaseUrl();
    const timezone = config.get('generic.timezone');
    const webhookBaseUrl = urlBaseWebhook + config.get('endpoints.webhook');
    const webhookTestBaseUrl = urlBaseWebhook + config.get('endpoints.webhookTest');
    const encryptionKey = await n8n_core_1.UserSettings.getEncryptionKey();
    if (encryptionKey === undefined) {
        throw new Error('No encryption key got found to decrypt the credentials!');
    }
    return {
        credentials,
        credentialsHelper: new _1.CredentialsHelper(credentials, encryptionKey),
        encryptionKey,
        executeWorkflow,
        restApiUrl: urlBaseWebhook + config.get('endpoints.rest'),
        timezone,
        webhookBaseUrl,
        webhookTestBaseUrl,
        currentNodeParameters,
    };
}
exports.getBase = getBase;
function getWorkflowHooksIntegrated(mode, executionId, workflowData, optionalParameters) {
    optionalParameters = optionalParameters || {};
    const hookFunctions = hookFunctionsSave(optionalParameters.parentProcessMode);
    return new n8n_workflow_1.WorkflowHooks(hookFunctions, mode, executionId, workflowData, optionalParameters);
}
exports.getWorkflowHooksIntegrated = getWorkflowHooksIntegrated;
function getWorkflowHooksMain(data, executionId) {
    const hookFunctions = hookFunctionsSave();
    const pushFunctions = hookFunctionsPush();
    for (const key of Object.keys(pushFunctions)) {
        hookFunctions[key].push.apply(hookFunctions[key], pushFunctions[key]);
    }
    return new n8n_workflow_1.WorkflowHooks(hookFunctions, data.executionMode, executionId, data.workflowData, { sessionId: data.sessionId, retryOf: data.retryOf });
}
exports.getWorkflowHooksMain = getWorkflowHooksMain;
//# sourceMappingURL=WorkflowExecuteAdditionalData.js.map