"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.accountFields = exports.accountOperations = void 0;
const GenericFunctions_1 = require("./GenericFunctions");
exports.accountOperations = [
    {
        displayName: 'Operation',
        name: 'operation',
        type: 'options',
        displayOptions: {
            show: {
                resource: [
                    'account',
                ],
            },
        },
        options: [
            {
                name: 'Create',
                value: 'create',
                description: 'Create an account',
            },
            {
                name: 'Delete',
                value: 'delete',
                description: 'Delete an account',
            },
            {
                name: 'Get',
                value: 'get',
                description: 'Get data of an account',
            },
            {
                name: 'Get All',
                value: 'getAll',
                description: 'Get data of all accounts',
            },
            {
                name: 'Update',
                value: 'update',
                description: 'Update an account',
            },
        ],
        default: 'create',
        description: 'The operation to perform.',
    },
];
exports.accountFields = [
    {
        displayName: 'Name',
        name: 'name',
        type: 'string',
        default: '',
        required: true,
        displayOptions: {
            show: {
                operation: [
                    'create',
                ],
                resource: [
                    'account',
                ],
            },
        },
        description: 'Account\'s name.',
    },
    {
        displayName: 'Additional Fields',
        name: 'additionalFields',
        type: 'collection',
        placeholder: 'Add Field',
        displayOptions: {
            show: {
                operation: [
                    'create',
                ],
                resource: [
                    'account',
                ],
            },
        },
        default: {},
        options: [
            {
                displayName: 'Account URL',
                name: 'accountUrl',
                type: 'string',
                default: '',
                description: `Account's website`,
            },
            {
                displayName: 'Fields',
                name: 'fields',
                placeholder: 'Add Custom Fields',
                description: 'Adds a custom fields to set also values which have not been predefined.',
                type: 'fixedCollection',
                typeOptions: {
                    multipleValues: true,
                },
                default: {},
                options: [
                    {
                        name: 'property',
                        displayName: 'Field',
                        values: [
                            {
                                displayName: 'Field ID',
                                name: 'customFieldId',
                                type: 'options',
                                typeOptions: {
                                    loadOptionsMethod: 'getAccountCustomFields',
                                },
                                default: '',
                                description: 'ID of the field to set.',
                            },
                            {
                                displayName: 'Field Value',
                                name: 'fieldValue',
                                type: 'string',
                                default: '',
                                description: 'Value of the field to set.',
                            },
                        ],
                    },
                ],
            },
        ],
    },
    {
        displayName: 'Account ID',
        name: 'accountId',
        type: 'number',
        displayOptions: {
            show: {
                operation: [
                    'update',
                ],
                resource: [
                    'account',
                ],
            },
        },
        default: 0,
        required: true,
        description: 'ID of the account to update.',
    },
    {
        displayName: 'Update Fields',
        name: 'updateFields',
        type: 'collection',
        description: 'The fields to update.',
        placeholder: 'Add Field',
        displayOptions: {
            show: {
                operation: [
                    'update',
                ],
                resource: [
                    'account',
                ],
            },
        },
        default: {},
        options: [
            {
                displayName: 'Name',
                name: 'name',
                type: 'string',
                default: '',
                description: 'Account\'s name.',
            },
            {
                displayName: 'Account URL',
                name: 'accountUrl',
                type: 'string',
                default: '',
                description: 'Account\'s website',
            },
            {
                displayName: 'Fields',
                name: 'fields',
                placeholder: 'Add Fields',
                description: 'Adds a custom fields to set also values which have not been predefined.',
                type: 'fixedCollection',
                typeOptions: {
                    multipleValues: true,
                },
                default: {},
                options: [
                    {
                        name: 'property',
                        displayName: 'Field',
                        values: [
                            {
                                displayName: 'Field ID',
                                name: 'customFieldId',
                                type: 'options',
                                typeOptions: {
                                    loadOptionsMethod: 'getAccountCustomFields',
                                },
                                default: '',
                                description: 'ID of the field to set.',
                            },
                            {
                                displayName: 'Field Value',
                                name: 'fieldValue',
                                type: 'string',
                                default: '',
                                description: 'Value of the field to set.',
                            },
                        ],
                    },
                ],
            },
        ],
    },
    {
        displayName: 'Account ID',
        name: 'accountId',
        type: 'number',
        displayOptions: {
            show: {
                operation: [
                    'delete',
                ],
                resource: [
                    'account',
                ],
            },
        },
        default: 0,
        required: true,
        description: 'ID of the account to delete.',
    },
    {
        displayName: 'Account ID',
        name: 'accountId',
        type: 'number',
        displayOptions: {
            show: {
                operation: [
                    'get',
                ],
                resource: [
                    'account',
                ],
            },
        },
        default: 0,
        required: true,
        description: 'ID of the account to get.',
    },
    ...GenericFunctions_1.activeCampaignDefaultGetAllProperties('account', 'getAll'),
    {
        displayName: 'Filters',
        name: 'filters',
        type: 'collection',
        placeholder: 'Add Filter',
        displayOptions: {
            show: {
                operation: [
                    'getAll',
                ],
                resource: [
                    'account',
                ],
            },
        },
        default: {},
        options: [
            {
                displayName: 'Search',
                name: 'search',
                type: 'string',
                default: '',
                description: 'Search by name',
            },
        ],
    },
];
//# sourceMappingURL=AccountDescription.js.map