"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.apiRequestAllItems = exports.apiRequest = void 0;
async function apiRequest(method, endpoint, body, query) {
    const credentials = this.getCredentials('airtableApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    query = query || {};
    query.api_key = credentials.apiKey;
    const options = {
        headers: {},
        method,
        body,
        qs: query,
        uri: `https://api.airtable.com/v0/${endpoint}`,
        json: true,
    };
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        if (error.statusCode === 401) {
            throw new Error('The Airtable credentials are not valid!');
        }
        if (error.response && error.response.body && error.response.body.error) {
            const airtableError = error.response.body.error;
            if (airtableError.type && airtableError.message) {
                throw new Error(`Airtable error response [${airtableError.type}]: ${airtableError.message}`);
            }
        }
        throw error;
    }
}
exports.apiRequest = apiRequest;
async function apiRequestAllItems(method, endpoint, body, query) {
    if (query === undefined) {
        query = {};
    }
    query.pageSize = 100;
    const returnData = [];
    let responseData;
    do {
        responseData = await apiRequest.call(this, method, endpoint, body, query);
        returnData.push.apply(returnData, responseData.records);
        query.offset = responseData.offset;
    } while (responseData.offset !== undefined);
    return {
        records: returnData,
    };
}
exports.apiRequestAllItems = apiRequestAllItems;
//# sourceMappingURL=GenericFunctions.js.map