"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateJSON = exports.clickupApiRequestAllItems = exports.clickupApiRequest = void 0;
async function clickupApiRequest(method, resource, body = {}, qs = {}, uri, option = {}) {
    const options = {
        headers: {
            'Content-Type': 'application/json',
        },
        method,
        qs,
        body,
        uri: uri || `https://api.clickup.com/api/v2${resource}`,
        json: true,
    };
    try {
        const authenticationMethod = this.getNodeParameter('authentication', 0);
        if (authenticationMethod === 'accessToken') {
            const credentials = this.getCredentials('clickUpApi');
            if (credentials === undefined) {
                throw new Error('No credentials got returned!');
            }
            options.headers['Authorization'] = credentials.accessToken;
            return await this.helpers.request(options);
        }
        else {
            const oAuth2Options = {
                keepBearer: false,
                tokenType: 'Bearer',
            };
            return await this.helpers.requestOAuth2.call(this, 'clickUpOAuth2Api', options, oAuth2Options);
        }
    }
    catch (error) {
        let errorMessage = error;
        if (error.err) {
            errorMessage = error.err;
        }
        throw new Error('ClickUp Error: ' + errorMessage);
    }
}
exports.clickupApiRequest = clickupApiRequest;
async function clickupApiRequestAllItems(propertyName, method, resource, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    query.page = 0;
    do {
        responseData = await clickupApiRequest.call(this, method, resource, body, query);
        returnData.push.apply(returnData, responseData[propertyName]);
        query.page++;
        if (query.limit && query.limit <= returnData.length) {
            return returnData;
        }
    } while (responseData[propertyName] &&
        responseData[propertyName].length !== 0);
    return returnData;
}
exports.clickupApiRequestAllItems = clickupApiRequestAllItems;
function validateJSON(json) {
    let result;
    try {
        result = JSON.parse(json);
    }
    catch (exception) {
        result = undefined;
    }
    return result;
}
exports.validateJSON = validateJSON;
//# sourceMappingURL=GenericFunctions.js.map