"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createDataFromParameters = exports.cockpitApiRequest = void 0;
async function cockpitApiRequest(method, resource, body = {}, uri, option = {}) {
    const credentials = this.getCredentials('cockpitApi');
    if (credentials === undefined) {
        throw new Error('No credentials available.');
    }
    let options = {
        headers: {
            Accept: 'application/json',
            'Content-Type': 'application/json',
        },
        method,
        qs: {
            token: credentials.accessToken,
        },
        body,
        uri: uri || `${credentials.url}/api${resource}`,
        json: true,
    };
    options = Object.assign({}, options, option);
    if (Object.keys(options.body).length === 0) {
        delete options.body;
    }
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        let errorMessage = error.message;
        if (error.error) {
            errorMessage = error.error.message || error.error.error;
        }
        throw new Error(`Cockpit error [${error.statusCode}]: ` + errorMessage);
    }
}
exports.cockpitApiRequest = cockpitApiRequest;
function createDataFromParameters(itemIndex) {
    const dataFieldsAreJson = this.getNodeParameter('jsonDataFields', itemIndex);
    if (dataFieldsAreJson) {
        return JSON.parse(this.getNodeParameter('dataFieldsJson', itemIndex, {}));
    }
    const uiDataFields = this.getNodeParameter('dataFieldsUi', itemIndex, {});
    const unpacked = {};
    if (uiDataFields.field === undefined) {
        return unpacked;
    }
    for (const field of uiDataFields.field) {
        unpacked[field.name] = field.value;
    }
    return unpacked;
}
exports.createDataFromParameters = createDataFromParameters;
//# sourceMappingURL=GenericFunctions.js.map