"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.convertKitApiRequest = void 0;
async function convertKitApiRequest(method, endpoint, body = {}, qs = {}, uri, option = {}) {
    const credentials = this.getCredentials('convertKitApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    let options = {
        headers: {
            'Content-Type': 'application/json',
        },
        method,
        qs,
        body,
        uri: uri || `https://api.convertkit.com/v3${endpoint}`,
        json: true,
    };
    options = Object.assign({}, options, option);
    if (Object.keys(options.body).length === 0) {
        delete options.body;
    }
    if (options.uri.includes('/automations/hooks')) {
        options.body['api_secret'] = credentials.apiSecret;
    }
    else {
        qs.api_secret = credentials.apiSecret;
    }
    if (Object.keys(options.qs).length === 0) {
        delete options.qs;
    }
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        let errorMessage = error;
        if (error.response && error.response.body && error.response.body.message) {
            errorMessage = error.response.body.message;
        }
        throw new Error(`ConvertKit error response: ${errorMessage}`);
    }
}
exports.convertKitApiRequest = convertKitApiRequest;
//# sourceMappingURL=GenericFunctions.js.map