"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.messageFields = exports.messageOperations = void 0;
exports.messageOperations = [
    {
        displayName: 'Operation',
        name: 'operation',
        type: 'options',
        displayOptions: {
            show: {
                resource: [
                    'message',
                ],
            },
        },
        options: [
            {
                name: 'Send',
                value: 'send',
                description: 'Send an email',
            },
            {
                name: 'Delete',
                value: 'delete',
                description: 'Delete a message',
            },
            {
                name: 'Get',
                value: 'get',
                description: 'Get a message',
            },
            {
                name: 'Get All',
                value: 'getAll',
                description: 'Get all messages',
            },
            {
                name: 'Reply',
                value: 'reply',
                description: 'Reply to an email',
            },
        ],
        default: 'send',
        description: 'The operation to perform.',
    },
];
exports.messageFields = [
    {
        displayName: 'Message ID',
        name: 'messageId',
        type: 'string',
        default: '',
        required: true,
        displayOptions: {
            show: {
                resource: [
                    'message',
                ],
                operation: [
                    'get',
                    'delete',
                ],
            },
        },
        placeholder: '172ce2c4a72cc243',
        description: 'The ID of the message you are operating on.',
    },
    {
        displayName: 'Thread ID',
        name: 'threadId',
        type: 'string',
        default: '',
        required: true,
        displayOptions: {
            show: {
                resource: [
                    'message',
                ],
                operation: [
                    'reply',
                ],
            },
        },
        placeholder: '172ce2c4a72cc243',
        description: 'The ID of the thread you are replying to.',
    },
    {
        displayName: 'Message ID',
        name: 'messageId',
        type: 'string',
        default: '',
        required: true,
        displayOptions: {
            show: {
                resource: [
                    'message',
                ],
                operation: [
                    'reply',
                ],
            },
        },
        placeholder: 'CAHNQoFsC6JMMbOBJgtjsqN0eEc+gDg2a=SQj-tWUebQeHMDgqQ@mail.gmail.com',
        description: 'The ID of the message you are replying to.',
    },
    {
        displayName: 'Subject',
        name: 'subject',
        type: 'string',
        default: '',
        required: true,
        displayOptions: {
            show: {
                resource: [
                    'message',
                ],
                operation: [
                    'reply',
                    'send',
                ],
            },
        },
        placeholder: 'Hello World!',
        description: 'The message subject.',
    },
    {
        displayName: 'Message',
        name: 'message',
        type: 'string',
        default: '',
        required: true,
        displayOptions: {
            show: {
                resource: [
                    'message',
                ],
                operation: [
                    'reply',
                    'send',
                ],
            },
        },
        placeholder: 'Hello World!',
        description: 'The message body. This can be in HTML.',
    },
    {
        displayName: 'To Email',
        name: 'toList',
        type: 'string',
        default: [],
        required: true,
        typeOptions: {
            multipleValues: true,
            multipleValueButtonText: 'Add To Email',
        },
        displayOptions: {
            show: {
                resource: [
                    'message',
                ],
                operation: [
                    'reply',
                    'send',
                ],
            },
        },
        placeholder: 'info@example.com',
        description: 'The email addresses of the recipients.',
    },
    {
        displayName: 'Additional Fields',
        name: 'additionalFields',
        type: 'collection',
        placeholder: 'Add Field',
        displayOptions: {
            show: {
                resource: [
                    'message',
                ],
                operation: [
                    'send',
                    'reply',
                ],
            },
        },
        default: {},
        options: [
            {
                displayName: 'CC Email',
                name: 'ccList',
                type: 'string',
                description: 'The email addresses of the copy recipients.',
                typeOptions: {
                    multipleValues: true,
                    multipleValueButtonText: 'Add CC Email',
                },
                placeholder: 'info@example.com',
                default: [],
            },
            {
                displayName: 'BCC Email',
                name: 'bccList',
                type: 'string',
                description: 'The email addresses of the blind copy recipients.',
                typeOptions: {
                    multipleValues: true,
                    multipleValueButtonText: 'Add BCC Email',
                },
                placeholder: 'info@example.com',
                default: [],
            },
            {
                displayName: 'Attachments',
                name: 'attachmentsUi',
                placeholder: 'Add Attachments',
                type: 'fixedCollection',
                typeOptions: {
                    multipleValues: true,
                },
                options: [
                    {
                        name: 'attachmentsBinary',
                        displayName: 'Attachments Binary',
                        values: [
                            {
                                displayName: 'Property',
                                name: 'property',
                                type: 'string',
                                default: '',
                                description: 'Name of the binary properties which contain data which should be added to email as attachment',
                            },
                        ],
                    },
                ],
                default: '',
                description: 'Array of supported attachments to add to the message.',
            },
        ],
    },
    {
        displayName: 'Additional Fields',
        name: 'additionalFields',
        type: 'collection',
        placeholder: 'Add Field',
        displayOptions: {
            show: {
                resource: [
                    'message',
                ],
                operation: [
                    'get',
                ],
            },
        },
        default: {},
        options: [
            {
                displayName: 'Format',
                name: 'format',
                type: 'options',
                options: [
                    {
                        name: 'Full',
                        value: 'full',
                        description: 'Returns the full email message data with body content parsed in the payload field',
                    },
                    {
                        name: 'Metadata',
                        value: 'metadata',
                        description: 'Returns only email message ID, labels, and email headers.',
                    },
                    {
                        name: 'Minimal',
                        value: 'minimal',
                        description: 'Returns only email message ID and labels; does not return the email headers, body, or payload',
                    },
                    {
                        name: 'RAW',
                        value: 'raw',
                        description: 'Returns the full email message data with body content in the raw field as a base64url encoded string; the payload field is not used.',
                    },
                    {
                        name: 'Resolved',
                        value: 'resolved',
                        description: 'Returns the full email with all data resolved and attachments saved as binary data.',
                    },
                ],
                default: 'resolved',
                description: 'The format to return the message in',
            },
            {
                displayName: 'Attachments Prefix',
                name: 'dataPropertyAttachmentsPrefixName',
                type: 'string',
                default: 'attachment_',
                displayOptions: {
                    hide: {
                        format: [
                            'full',
                            'metadata',
                            'minimal',
                            'raw',
                        ],
                    },
                },
                description: 'Prefix for name of the binary property to which to<br />write the attachments. An index starting with 0 will be added.<br />So if name is "attachment_" the first attachment is saved to "attachment_0"',
            },
        ],
    },
    {
        displayName: 'Return All',
        name: 'returnAll',
        type: 'boolean',
        displayOptions: {
            show: {
                operation: [
                    'getAll',
                ],
                resource: [
                    'message',
                ],
            },
        },
        default: false,
        description: 'If all results should be returned or only up to a given limit.',
    },
    {
        displayName: 'Limit',
        name: 'limit',
        type: 'number',
        displayOptions: {
            show: {
                operation: [
                    'getAll',
                ],
                resource: [
                    'message',
                ],
                returnAll: [
                    false,
                ],
            },
        },
        typeOptions: {
            minValue: 1,
            maxValue: 500,
        },
        default: 10,
        description: 'How many results to return.',
    },
    {
        displayName: 'Additional Fields',
        name: 'additionalFields',
        type: 'collection',
        placeholder: 'Add Field',
        default: {},
        displayOptions: {
            show: {
                operation: [
                    'getAll',
                ],
                resource: [
                    'message',
                ],
            },
        },
        options: [
            {
                displayName: 'Attachments Prefix',
                name: 'dataPropertyAttachmentsPrefixName',
                type: 'string',
                default: 'attachment_',
                displayOptions: {
                    hide: {
                        format: [
                            'full',
                            'ids',
                            'metadata',
                            'minimal',
                            'raw',
                        ],
                    },
                },
                description: 'Prefix for name of the binary property to which to<br />write the attachments. An index starting with 0 will be added.<br />So if name is "attachment_" the first attachment is saved to "attachment_0"',
            },
            {
                displayName: 'Format',
                name: 'format',
                type: 'options',
                options: [
                    {
                        name: 'Full',
                        value: 'full',
                        description: 'Returns the full email message data with body content parsed in the payload field',
                    },
                    {
                        name: 'IDs',
                        value: 'ids',
                        description: 'Returns only the IDs of the emails',
                    },
                    {
                        name: 'Metadata',
                        value: 'metadata',
                        description: 'Returns only email message ID, labels, and email headers.',
                    },
                    {
                        name: 'Minimal',
                        value: 'minimal',
                        description: 'Returns only email message ID and labels; does not return the email headers, body, or payload',
                    },
                    {
                        name: 'RAW',
                        value: 'raw',
                        description: 'Returns the full email message data with body content in the raw field as a base64url encoded string; the payload field is not used.',
                    },
                    {
                        name: 'Resolved',
                        value: 'resolved',
                        description: 'Returns the full email with all data resolved and attachments saved as binary data.',
                    },
                ],
                default: 'resolved',
                description: 'The format to return the message in',
            },
            {
                displayName: 'Include Spam Trash',
                name: 'includeSpamTrash',
                type: 'boolean',
                default: false,
                description: 'Include messages from SPAM and TRASH in the results.',
            },
            {
                displayName: 'Label IDs',
                name: 'labelIds',
                type: 'multiOptions',
                typeOptions: {
                    loadOptionsMethod: 'getLabels',
                },
                default: [],
                description: 'Only return messages with labels that match all of the specified label IDs.',
            },
            {
                displayName: 'Query',
                name: 'q',
                type: 'string',
                typeOptions: {
                    alwaysOpenEditWindow: true,
                },
                default: '',
                description: `Only return messages matching the specified query.</br>
				Supports the same query format as the Gmail search box.</br>
				For example, "from:someuser@example.com rfc822msgid:<somemsgid@example.com> is:unread".</br>
				Parameter cannot be used when accessing the api using the gmail.metadata scope.`,
            },
        ],
    },
];
//# sourceMappingURL=MessageDescription.js.map