"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.harvestApiRequestAllItems = exports.harvestApiRequest = void 0;
async function harvestApiRequest(method, qs = {}, uri, body = {}, option = {}) {
    const credentials = this.getCredentials('harvestApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    qs.access_token = credentials.accessToken;
    qs.account_id = credentials.accountId;
    const queryStringElements = [];
    for (const key of Object.keys(qs)) {
        if (Array.isArray(qs[key])) {
            qs[key].forEach(value => {
                queryStringElements.push(`${key}=${value}`);
            });
        }
        else {
            queryStringElements.push(`${key}=${qs[key]}`);
        }
    }
    let options = {
        method,
        body,
        uri: `https://api.harvestapp.com/v2/${uri}?${queryStringElements.join('&')}`,
        json: true,
        headers: {
            "User-Agent": "Harvest API",
        },
    };
    options = Object.assign({}, options, option);
    if (Object.keys(options.body).length === 0) {
        delete options.body;
    }
    try {
        const result = await this.helpers.request(options);
        return result;
    }
    catch (error) {
        if (error.statusCode === 401) {
            throw new Error('The Harvest credentials are not valid!');
        }
        if (error.error && error.error.message) {
            throw new Error(`Harvest error response [${error.statusCode}]: ${error.error.message}`);
        }
        throw new Error(`Harvest error response: ${error.message}`);
    }
}
exports.harvestApiRequest = harvestApiRequest;
async function harvestApiRequestAllItems(method, qs = {}, uri, resource, body = {}, option = {}) {
    const returnData = [];
    let responseData;
    try {
        do {
            responseData = await harvestApiRequest.call(this, method, qs, uri, body, option);
            qs.page = responseData.next_page;
            returnData.push.apply(returnData, responseData[resource]);
        } while (responseData.next_page);
        return returnData;
    }
    catch (error) {
        throw error;
    }
}
exports.harvestApiRequestAllItems = harvestApiRequestAllItems;
//# sourceMappingURL=GenericFunctions.js.map