"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateJSON = exports.hubspotApiRequestAllItems = exports.hubspotApiRequest = void 0;
async function hubspotApiRequest(method, endpoint, body = {}, query = {}, uri) {
    let authenticationMethod = this.getNodeParameter('authentication', 0);
    if (this.getNode().type.includes('Trigger')) {
        authenticationMethod = 'developerApi';
    }
    const options = {
        method,
        qs: query,
        uri: uri || `https://api.hubapi.com${endpoint}`,
        body,
        json: true,
        useQuerystring: true,
    };
    try {
        if (authenticationMethod === 'apiKey') {
            const credentials = this.getCredentials('hubspotApi');
            options.qs.hapikey = credentials.apiKey;
            return await this.helpers.request(options);
        }
        else if (authenticationMethod === 'developerApi') {
            const credentials = this.getCredentials('hubspotDeveloperApi');
            options.qs.hapikey = credentials.apiKey;
            return await this.helpers.request(options);
        }
        else {
            return await this.helpers.requestOAuth2.call(this, 'hubspotOAuth2Api', options, { tokenType: 'Bearer' });
        }
    }
    catch (error) {
        let errorMessages;
        if (error.response && error.response.body) {
            if (error.response.body.message) {
                errorMessages = [error.response.body.message];
            }
            else if (error.response.body.errors) {
                errorMessages = error.response.body.errors;
                if (errorMessages[0].message) {
                    errorMessages = errorMessages.map(errorItem => errorItem.message);
                }
            }
            throw new Error(`Hubspot error response [${error.statusCode}]: ${errorMessages.join('|')}`);
        }
        throw error;
    }
}
exports.hubspotApiRequest = hubspotApiRequest;
async function hubspotApiRequestAllItems(propertyName, method, endpoint, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    query.limit = query.limit || 250;
    query.count = 100;
    body.limit = body.limit || 100;
    do {
        responseData = await hubspotApiRequest.call(this, method, endpoint, body, query);
        query.offset = responseData.offset;
        query['vid-offset'] = responseData['vid-offset'];
        returnData.push.apply(returnData, responseData[propertyName]);
        if (query.limit && query.limit <= returnData.length) {
            return returnData;
        }
    } while (responseData['has-more'] !== undefined &&
        responseData['has-more'] !== null &&
        responseData['has-more'] !== false);
    return returnData;
}
exports.hubspotApiRequestAllItems = hubspotApiRequestAllItems;
function validateJSON(json) {
    let result;
    try {
        result = JSON.parse(json);
    }
    catch (exception) {
        result = '';
    }
    return result;
}
exports.validateJSON = validateJSON;
//# sourceMappingURL=GenericFunctions.js.map