"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.invoiceNinjaApiRequestAllItems = exports.invoiceNinjaApiRequest = void 0;
const lodash_1 = require("lodash");
async function invoiceNinjaApiRequest(method, endpoint, body = {}, query, uri) {
    const credentials = this.getCredentials('invoiceNinjaApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    const baseUrl = credentials.url || 'https://app.invoiceninja.com';
    const options = {
        headers: {
            Accept: 'application/json',
            'X-Ninja-Token': credentials.apiToken,
        },
        method,
        qs: query,
        uri: uri || `${baseUrl}/api/v1${endpoint}`,
        body,
        json: true,
    };
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        if (error.response && error.response.body && error.response.body.errors) {
            const errorMessages = Object.keys(error.response.body.errors).map(errorName => {
                return error.response.body.errors[errorName].join('');
            });
            throw new Error(`Invoice Ninja error response [${error.statusCode}]: ${errorMessages.join(' | ')}`);
        }
        throw error;
    }
}
exports.invoiceNinjaApiRequest = invoiceNinjaApiRequest;
async function invoiceNinjaApiRequestAllItems(propertyName, method, endpoint, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    let uri;
    query.per_page = 100;
    do {
        responseData = await invoiceNinjaApiRequest.call(this, method, endpoint, body, query, uri);
        const next = lodash_1.get(responseData, 'meta.pagination.links.next');
        if (next) {
            uri = next;
        }
        returnData.push.apply(returnData, responseData[propertyName]);
    } while (responseData.meta !== undefined &&
        responseData.meta.pagination &&
        responseData.meta.pagination.links &&
        responseData.meta.pagination.links.next);
    return returnData;
}
exports.invoiceNinjaApiRequestAllItems = invoiceNinjaApiRequestAllItems;
//# sourceMappingURL=GenericFunctions.js.map