"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.allEvents = exports.getId = exports.eventExists = exports.validateJSON = exports.jiraSoftwareCloudApiRequestAllItems = exports.jiraSoftwareCloudApiRequest = void 0;
async function jiraSoftwareCloudApiRequest(endpoint, method, body = {}, query, uri) {
    let data;
    let domain;
    const jiraVersion = this.getNodeParameter('jiraVersion', 0);
    let jiraCredentials;
    if (jiraVersion === 'server') {
        jiraCredentials = this.getCredentials('jiraSoftwareServerApi');
    }
    else {
        jiraCredentials = this.getCredentials('jiraSoftwareCloudApi');
    }
    if (jiraCredentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    if (jiraVersion === 'server') {
        domain = jiraCredentials.domain;
        data = Buffer.from(`${jiraCredentials.email}:${jiraCredentials.password}`).toString('base64');
    }
    else {
        domain = jiraCredentials.domain;
        data = Buffer.from(`${jiraCredentials.email}:${jiraCredentials.apiToken}`).toString('base64');
    }
    const options = {
        headers: {
            Authorization: `Basic ${data}`,
            Accept: 'application/json',
            'Content-Type': 'application/json',
        },
        method,
        qs: query,
        uri: uri || `${domain}/rest${endpoint}`,
        body,
        json: true,
    };
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        let errorMessage = error.message;
        if (error.response.body) {
            if (error.response.body.errorMessages && error.response.body.errorMessages.length) {
                errorMessage = JSON.stringify(error.response.body.errorMessages);
            }
            else {
                errorMessage = error.response.body.message || error.response.body.error || error.response.body.errors || error.message;
            }
        }
        if (typeof errorMessage !== 'string') {
            errorMessage = JSON.stringify(errorMessage);
        }
        throw new Error(`Jira error response [${error.statusCode}]: ${errorMessage}`);
    }
}
exports.jiraSoftwareCloudApiRequest = jiraSoftwareCloudApiRequest;
async function jiraSoftwareCloudApiRequestAllItems(propertyName, endpoint, method, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    query.startAt = 0;
    body.startAt = 0;
    query.maxResults = 100;
    body.maxResults = 100;
    do {
        responseData = await jiraSoftwareCloudApiRequest.call(this, endpoint, method, body, query);
        returnData.push.apply(returnData, responseData[propertyName]);
        query.startAt = responseData.startAt + responseData.maxResults;
        body.startAt = responseData.startAt + responseData.maxResults;
    } while ((responseData.startAt + responseData.maxResults < responseData.total));
    return returnData;
}
exports.jiraSoftwareCloudApiRequestAllItems = jiraSoftwareCloudApiRequestAllItems;
function validateJSON(json) {
    let result;
    try {
        result = JSON.parse(json);
    }
    catch (exception) {
        result = '';
    }
    return result;
}
exports.validateJSON = validateJSON;
function eventExists(currentEvents, webhookEvents) {
    for (const currentEvent of currentEvents) {
        if (!webhookEvents.includes(currentEvent)) {
            return false;
        }
    }
    return true;
}
exports.eventExists = eventExists;
function getId(url) {
    return url.split('/').pop();
}
exports.getId = getId;
exports.allEvents = [
    'board_created',
    'board_updated',
    'board_deleted',
    'board_configuration_changed',
    'comment_created',
    'comment_updated',
    'comment_deleted',
    'jira:issue_created',
    'jira:issue_updated',
    'jira:issue_deleted',
    'option_voting_changed',
    'option_watching_changed',
    'option_unassigned_issues_changed',
    'option_subtasks_changed',
    'option_attachments_changed',
    'option_issuelinks_changed',
    'option_timetracking_changed',
    'project_created',
    'project_updated',
    'project_deleted',
    'sprint_created',
    'sprint_deleted',
    'sprint_updated',
    'sprint_started',
    'sprint_closed',
    'user_created',
    'user_updated',
    'user_deleted',
    'jira:version_released',
    'jira:version_unreleased',
    'jira:version_created',
    'jira:version_moved',
    'jira:version_updated',
    'jira:version_deleted',
    'issuelink_created',
    'issuelink_deleted',
    'worklog_created',
    'worklog_updated',
    'worklog_deleted',
];
//# sourceMappingURL=GenericFunctions.js.map