"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Mailjet = void 0;
const GenericFunctions_1 = require("./GenericFunctions");
const EmailDescription_1 = require("./EmailDescription");
const SmsDescription_1 = require("./SmsDescription");
class Mailjet {
    constructor() {
        this.description = {
            displayName: 'Mailjet',
            name: 'mailjet',
            icon: 'file:mailjet.png',
            group: ['output'],
            version: 1,
            subtitle: '={{$parameter["operation"] + ": " + $parameter["resource"]}}',
            description: 'Consume Mailjet API',
            defaults: {
                name: 'Mailjet',
                color: '#ff9f48',
            },
            inputs: ['main'],
            outputs: ['main'],
            credentials: [
                {
                    name: 'mailjetEmailApi',
                    required: true,
                    displayOptions: {
                        show: {
                            resource: [
                                'email',
                            ],
                        },
                    },
                },
                {
                    name: 'mailjetSmsApi',
                    required: true,
                    displayOptions: {
                        show: {
                            resource: [
                                'sms',
                            ],
                        },
                    },
                },
            ],
            properties: [
                {
                    displayName: 'Resource',
                    name: 'resource',
                    type: 'options',
                    options: [
                        {
                            name: 'Email',
                            value: 'email',
                        },
                        {
                            name: 'SMS',
                            value: 'sms',
                        },
                    ],
                    default: 'email',
                    description: 'Resource to consume.',
                },
                ...EmailDescription_1.emailOperations,
                ...EmailDescription_1.emailFields,
                ...SmsDescription_1.smsOperations,
                ...SmsDescription_1.smsFields,
            ],
        };
    }
    async execute() {
        const items = this.getInputData();
        const returnData = [];
        const length = items.length;
        let responseData;
        const resource = this.getNodeParameter('resource', 0);
        const operation = this.getNodeParameter('operation', 0);
        for (let i = 0; i < length; i++) {
            if (resource === 'email') {
                if (operation === 'send') {
                    const fromEmail = this.getNodeParameter('fromEmail', i);
                    const htmlBody = this.getNodeParameter('html', i);
                    const textBody = this.getNodeParameter('text', i);
                    const subject = this.getNodeParameter('subject', i);
                    const additionalFields = this.getNodeParameter('additionalFields', i);
                    const toEmail = this.getNodeParameter('toEmail', i).split(',');
                    const variables = this.getNodeParameter('variablesUi', i).variablesValues;
                    const body = {
                        Messages: [
                            {
                                From: {
                                    email: fromEmail,
                                },
                                subject,
                                to: [],
                                Cc: [],
                                Bcc: [],
                                Variables: {},
                            },
                        ],
                    };
                    for (const email of toEmail) {
                        body.Messages[0].to.push({
                            email,
                        });
                    }
                    if (variables) {
                        for (const variable of variables) {
                            body.Messages[0].Variables[variable.name] = variable.value;
                        }
                    }
                    if (htmlBody) {
                        body.Messages[0].HTMLPart = htmlBody;
                    }
                    if (textBody) {
                        body.Messages[0].TextPart = textBody;
                    }
                    if (additionalFields.bccEmail) {
                        const bccEmail = additionalFields.bccEmail.split(',');
                        for (const email of bccEmail) {
                            body.Messages[0].Bcc.push({
                                email,
                            });
                        }
                    }
                    if (additionalFields.ccEmail) {
                        const ccEmail = additionalFields.ccEmail.split(',');
                        for (const email of ccEmail) {
                            body.Messages[0].Cc.push({
                                email,
                            });
                        }
                    }
                    if (additionalFields.trackOpens) {
                        body.Messages[0].TrackOpens = additionalFields.trackOpens;
                    }
                    if (additionalFields.trackClicks) {
                        body.Messages[0].TrackClicks = additionalFields.trackClicks;
                    }
                    if (additionalFields.fromName) {
                        body.Messages[0].From.name = additionalFields.fromName;
                    }
                    if (additionalFields.templateLanguage) {
                        body.Messages[0].From.TemplateLanguage = additionalFields.templateLanguage;
                    }
                    if (additionalFields.priority) {
                        body.Messages[0].Priority = additionalFields.priority;
                    }
                    responseData = await GenericFunctions_1.mailjetApiRequest.call(this, 'POST', '/v3.1/send', body);
                    responseData = responseData.Messages;
                }
                if (operation === 'sendTemplate') {
                    const fromEmail = this.getNodeParameter('fromEmail', i);
                    const templateId = parseInt(this.getNodeParameter('templateId', i), 10);
                    const subject = this.getNodeParameter('subject', i);
                    const variables = this.getNodeParameter('variablesUi', i).variablesValues;
                    const additionalFields = this.getNodeParameter('additionalFields', i);
                    const toEmail = this.getNodeParameter('toEmail', i).split(',');
                    const body = {
                        Messages: [
                            {
                                From: {
                                    email: fromEmail,
                                },
                                Subject: subject,
                                to: [],
                                Cc: [],
                                Bcc: [],
                                Variables: {},
                                TemplateID: templateId,
                            },
                        ],
                    };
                    for (const email of toEmail) {
                        body.Messages[0].to.push({
                            email,
                        });
                    }
                    if (variables) {
                        for (const variable of variables) {
                            body.Messages[0].Variables[variable.name] = variable.value;
                        }
                    }
                    if (additionalFields.bccEmail) {
                        const bccEmail = additionalFields.bccEmail.split(',');
                        for (const email of bccEmail) {
                            body.Messages[0].Bcc.push({
                                email,
                            });
                        }
                    }
                    if (additionalFields.ccEmail) {
                        const ccEmail = additionalFields.ccEmail.split(',');
                        for (const email of ccEmail) {
                            body.Messages[0].Cc.push({
                                email,
                            });
                        }
                    }
                    if (additionalFields.trackOpens) {
                        body.Messages[0].TrackOpens = additionalFields.trackOpens;
                    }
                    if (additionalFields.trackClicks) {
                        body.Messages[0].TrackClicks = additionalFields.trackClicks;
                    }
                    if (additionalFields.fromName) {
                        body.Messages[0].From.name = additionalFields.fromName;
                    }
                    if (additionalFields.templateLanguage) {
                        body.Messages[0].From.TemplateLanguage = additionalFields.templateLanguage;
                    }
                    if (additionalFields.priority) {
                        body.Messages[0].Priority = additionalFields.priority;
                    }
                    responseData = await GenericFunctions_1.mailjetApiRequest.call(this, 'POST', '/v3.1/send', body);
                    responseData = responseData.Messages;
                }
            }
            if (resource === 'sms') {
                if (operation === 'send') {
                    const from = this.getNodeParameter('from', i);
                    const to = this.getNodeParameter('to', i);
                    const text = this.getNodeParameter('text', i);
                    const body = {
                        From: from,
                        To: to,
                        Text: text,
                    };
                    responseData = await GenericFunctions_1.mailjetApiRequest.call(this, 'POST', '/v4/sms-send', body);
                }
            }
            if (Array.isArray(responseData)) {
                returnData.push.apply(returnData, responseData);
            }
            else {
                returnData.push(responseData);
            }
        }
        return [this.helpers.returnJsonArray(returnData)];
    }
}
exports.Mailjet = Mailjet;
//# sourceMappingURL=Mailjet.node.js.map