"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateJSON = exports.mauticApiRequestAllItems = exports.mauticApiRequest = exports.getErrors = void 0;
function getErrors(error) {
    const returnErrors = [];
    for (const errorItem of error.errors) {
        returnErrors.push(errorItem.message);
    }
    return returnErrors.join(', ');
}
exports.getErrors = getErrors;
async function mauticApiRequest(method, endpoint, body = {}, query, uri) {
    const authenticationMethod = this.getNodeParameter('authentication', 0, 'credentials');
    const options = {
        headers: {},
        method,
        qs: query,
        uri: uri || `/api${endpoint}`,
        body,
        json: true,
    };
    try {
        let returnData;
        if (authenticationMethod === 'credentials') {
            const credentials = this.getCredentials('mauticApi');
            const base64Key = Buffer.from(`${credentials.username}:${credentials.password}`).toString('base64');
            options.headers.Authorization = `Basic ${base64Key}`;
            options.uri = `${credentials.url}${options.uri}`;
            returnData = await this.helpers.request(options);
        }
        else {
            const credentials = this.getCredentials('mauticOAuth2Api');
            options.uri = `${credentials.url}${options.uri}`;
            returnData = await this.helpers.requestOAuth2.call(this, 'mauticOAuth2Api', options);
        }
        if (returnData.errors) {
            throw new Error(getErrors(returnData));
        }
        return returnData;
    }
    catch (error) {
        if (error.response && error.response.body && error.response.body.errors) {
            throw new Error('Mautic Error: ' + getErrors(error.response.body));
        }
        throw new Error(`Mautic Error: ${error.message}`);
    }
}
exports.mauticApiRequest = mauticApiRequest;
async function mauticApiRequestAllItems(propertyName, method, endpoint, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    let data = [];
    query.limit = 30;
    query.start = 0;
    do {
        responseData = await mauticApiRequest.call(this, method, endpoint, body, query);
        const values = Object.values(responseData[propertyName]);
        for (const value of values) {
            data.push(value);
        }
        returnData.push.apply(returnData, data);
        query.start++;
        data = [];
    } while (responseData.total !== undefined &&
        ((query.limit * query.start) - parseInt(responseData.total, 10)) < 0);
    return returnData;
}
exports.mauticApiRequestAllItems = mauticApiRequestAllItems;
function validateJSON(json) {
    let result;
    try {
        result = JSON.parse(json);
    }
    catch (exception) {
        result = undefined;
    }
    return result;
}
exports.validateJSON = validateJSON;
//# sourceMappingURL=GenericFunctions.js.map