"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mediumApiRequest = void 0;
async function mediumApiRequest(method, endpoint, body = {}, query = {}, uri) {
    const authenticationMethod = this.getNodeParameter('authentication', 0);
    const options = {
        method,
        headers: {
            'Accept': 'application/json',
            'Content-Type': 'application/json',
            'Accept-Charset': 'utf-8',
        },
        qs: query,
        uri: uri || `https://api.medium.com/v1${endpoint}`,
        body,
        json: true,
    };
    try {
        if (authenticationMethod === 'accessToken') {
            const credentials = this.getCredentials('mediumApi');
            if (credentials === undefined) {
                throw new Error('No credentials got returned!');
            }
            options.headers['Authorization'] = `Bearer ${credentials.accessToken}`;
            return await this.helpers.request(options);
        }
        else {
            return await this.helpers.requestOAuth2.call(this, 'mediumOAuth2Api', options);
        }
    }
    catch (error) {
        if (error.statusCode === 401) {
            throw new Error('The Medium credentials are not valid!');
        }
        throw error;
    }
}
exports.mediumApiRequest = mediumApiRequest;
//# sourceMappingURL=GenericFunctions.js.map