"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.extractDeleteValues = exports.extractUpdateCondition = exports.extractUpdateSet = exports.extractValues = exports.executeQueryQueue = exports.createTableStruct = exports.copyInputItem = void 0;
function copyInputItem(item, properties) {
    const newItem = {};
    for (const property of properties) {
        if (item.json[property] === undefined) {
            newItem[property] = null;
        }
        else {
            newItem[property] = JSON.parse(JSON.stringify(item.json[property]));
        }
    }
    return newItem;
}
exports.copyInputItem = copyInputItem;
function createTableStruct(getNodeParam, items, additionalProperties = [], keyName) {
    return items.reduce((tables, item, index) => {
        const table = getNodeParam('table', index);
        const columnString = getNodeParam('columns', index);
        const columns = columnString.split(',').map(column => column.trim());
        const itemCopy = copyInputItem(item, columns.concat(additionalProperties));
        const keyParam = keyName
            ? getNodeParam(keyName, index)
            : undefined;
        if (tables[table] === undefined) {
            tables[table] = {};
        }
        if (tables[table][columnString] === undefined) {
            tables[table][columnString] = [];
        }
        if (keyName) {
            itemCopy[keyName] = keyParam;
        }
        tables[table][columnString].push(itemCopy);
        return tables;
    }, {});
}
exports.createTableStruct = createTableStruct;
function executeQueryQueue(tables, buildQueryQueue) {
    return Promise.all(Object.keys(tables).map(table => {
        const columnsResults = Object.keys(tables[table]).map(columnString => {
            return Promise.all(buildQueryQueue({
                table,
                columnString,
                items: tables[table][columnString],
            }));
        });
        return Promise.all(columnsResults);
    }));
}
exports.executeQueryQueue = executeQueryQueue;
function extractValues(item) {
    return `(${Object.values(item)
        .map(val => (typeof val === 'string' ? `'${val}'` : val))
        .join(',')})`;
}
exports.extractValues = extractValues;
function extractUpdateSet(item, columns) {
    return columns
        .map(column => `${column} = ${typeof item[column] === 'string' ? `'${item[column]}'` : item[column]}`)
        .join(',');
}
exports.extractUpdateSet = extractUpdateSet;
function extractUpdateCondition(item, key) {
    return `${key} = ${typeof item[key] === 'string' ? `'${item[key]}'` : item[key]}`;
}
exports.extractUpdateCondition = extractUpdateCondition;
function extractDeleteValues(items, key) {
    return `(${items
        .map(item => (typeof item[key] === 'string' ? `'${item[key]}'` : item[key]))
        .join(',')})`;
}
exports.extractDeleteValues = extractDeleteValues;
//# sourceMappingURL=GenericFunctions.js.map