"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.msg91ApiRequest = void 0;
async function msg91ApiRequest(method, endpoint, body, query) {
    const credentials = this.getCredentials('msg91Api');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    if (query === undefined) {
        query = {};
    }
    query.authkey = credentials.authkey;
    const options = {
        method,
        form: body,
        qs: query,
        uri: `https://api.msg91.com/api${endpoint}`,
        json: true,
    };
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        if (error.statusCode === 401) {
            throw new Error('The MSG91 credentials are not valid!');
        }
        if (error.response && error.response.body && error.response.body.message) {
            let errorMessage = `MSG91 error response [${error.statusCode}]: ${error.response.body.message}`;
            if (error.response.body.more_info) {
                errorMessage = `errorMessage (${error.response.body.more_info})`;
            }
            throw new Error(errorMessage);
        }
        throw error;
    }
}
exports.msg91ApiRequest = msg91ApiRequest;
//# sourceMappingURL=GenericFunctions.js.map