"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolveMember = exports.resolveIdentities = exports.orbitApiRequestAllItems = exports.orbitApiRequest = void 0;
async function orbitApiRequest(method, resource, body = {}, qs = {}, uri, option = {}) {
    try {
        const credentials = this.getCredentials('orbitApi');
        if (credentials === undefined) {
            throw new Error('No credentials got returned!');
        }
        let options = {
            headers: {
                Authorization: `Bearer ${credentials.accessToken}`,
            },
            method,
            qs,
            body,
            uri: uri || `https://app.orbit.love/api/v1${resource}`,
            json: true,
        };
        options = Object.assign({}, options, option);
        return await this.helpers.request(options);
    }
    catch (error) {
        if (error.response && error.response.body && error.response.body.message) {
            const errorBody = error.response.body;
            throw new Error(`Orbit error response [${error.statusCode}]: ${errorBody.message}`);
        }
        throw error;
    }
}
exports.orbitApiRequest = orbitApiRequest;
async function orbitApiRequestAllItems(propertyName, method, resource, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    query.page = 1;
    do {
        responseData = await orbitApiRequest.call(this, method, resource, body, query);
        returnData.push.apply(returnData, responseData[propertyName]);
        if (query.resolveIdentities === true) {
            resolveIdentities(responseData);
        }
        if (query.resolveMember === true) {
            resolveMember(responseData);
        }
        query.page++;
        if (query.limit && (returnData.length >= query.limit)) {
            return returnData;
        }
    } while (responseData.data.length !== 0);
    return returnData;
}
exports.orbitApiRequestAllItems = orbitApiRequestAllItems;
function resolveIdentities(responseData) {
    const identities = {};
    for (const data of responseData.included) {
        identities[data.id] = data;
    }
    if (!Array.isArray(responseData.data)) {
        responseData.data = [responseData.data];
    }
    for (let i = 0; i < responseData.data.length; i++) {
        for (let y = 0; y < responseData.data[i].relationships.identities.data.length; y++) {
            responseData.data[i].relationships.identities.data[y] = identities[responseData.data[i].relationships.identities.data[y].id];
        }
    }
}
exports.resolveIdentities = resolveIdentities;
function resolveMember(responseData) {
    const members = {};
    for (const data of responseData.included) {
        members[data.id] = data;
    }
    if (!Array.isArray(responseData.data)) {
        responseData.data = [responseData.data];
    }
    for (let i = 0; i < responseData.data.length; i++) {
        responseData.data[i].relationships.member.data = members[responseData.data[i].relationships.member.data.id];
    }
}
exports.resolveMember = resolveMember;
//# sourceMappingURL=GenericFunctions.js.map