"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.pgUpdate = exports.pgInsert = exports.pgQuery = exports.getItemCopy = void 0;
function getItemCopy(items, properties) {
    let newItem;
    return items.map(item => {
        newItem = {};
        for (const property of properties) {
            if (item.json[property] === undefined) {
                newItem[property] = null;
            }
            else {
                newItem[property] = JSON.parse(JSON.stringify(item.json[property]));
            }
        }
        return newItem;
    });
}
exports.getItemCopy = getItemCopy;
function pgQuery(getNodeParam, pgp, db, input) {
    const queries = [];
    for (let i = 0; i < input.length; i++) {
        queries.push(getNodeParam('query', i));
    }
    return db.any(pgp.helpers.concat(queries));
}
exports.pgQuery = pgQuery;
async function pgInsert(getNodeParam, pgp, db, items) {
    const table = getNodeParam('table', 0);
    const schema = getNodeParam('schema', 0);
    let returnFields = getNodeParam('returnFields', 0).split(',');
    const columnString = getNodeParam('columns', 0);
    const columns = columnString.split(',').map(column => column.trim());
    const cs = new pgp.helpers.ColumnSet(columns);
    const te = new pgp.helpers.TableName({ table, schema });
    const insertItems = getItemCopy(items, columns);
    returnFields = returnFields.map(value => value.trim()).filter(value => !!value);
    const query = pgp.helpers.insert(insertItems, cs, te) +
        (returnFields.length ? ` RETURNING ${returnFields.join(',')}` : '');
    const insertData = await db.manyOrNone(query);
    return [insertData, insertItems];
}
exports.pgInsert = pgInsert;
async function pgUpdate(getNodeParam, pgp, db, items) {
    const table = getNodeParam('table', 0);
    const schema = getNodeParam('schema', 0);
    const updateKey = getNodeParam('updateKey', 0);
    const columnString = getNodeParam('columns', 0);
    const columns = columnString.split(',').map(column => column.trim());
    const te = new pgp.helpers.TableName({ table, schema });
    if (!columns.includes(updateKey)) {
        columns.unshift(updateKey);
    }
    const updateItems = getItemCopy(items, columns);
    const query = pgp.helpers.update(updateItems, columns, te) + ' WHERE v.' + updateKey + ' = t.' + updateKey;
    await db.none(query);
    return updateItems;
}
exports.pgUpdate = pgUpdate;
//# sourceMappingURL=Postgres.node.functions.js.map