"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.pushoverApiRequest = void 0;
async function pushoverApiRequest(method, path, body = {}, qs = {}, option = {}) {
    const credentials = this.getCredentials('pushoverApi');
    if (method === 'GET') {
        qs.token = credentials.apiKey;
    }
    else {
        body.token = credentials.apiKey;
    }
    const options = {
        method,
        formData: body,
        qs,
        uri: `https://api.pushover.net/1${path}`,
        json: true,
    };
    try {
        if (Object.keys(body).length === 0) {
            delete options.body;
        }
        return await this.helpers.request.call(this, options);
    }
    catch (error) {
        if (error.response && error.response.body && error.response.body.errors) {
            let errors = error.response.body.errors;
            errors = errors.map((e) => e);
            throw new Error(`PushOver error response [${error.statusCode}]: ${errors.join('|')}`);
        }
        throw error;
    }
}
exports.pushoverApiRequest = pushoverApiRequest;
//# sourceMappingURL=GenericFunctions.js.map