"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Rundeck = void 0;
const RundeckApi_1 = require("./RundeckApi");
class Rundeck {
    constructor() {
        this.description = {
            displayName: 'Rundeck',
            name: 'rundeck',
            icon: 'file:rundeck.png',
            group: ['transform'],
            version: 1,
            subtitle: '={{$parameter["operation"] + ": " + $parameter["resource"]}}',
            description: 'Manage Rundeck API',
            defaults: {
                name: 'Rundeck',
                color: '#F73F39',
            },
            inputs: ['main'],
            outputs: ['main'],
            credentials: [
                {
                    name: 'rundeckApi',
                    required: true,
                },
            ],
            properties: [
                {
                    displayName: 'Resource',
                    name: 'resource',
                    type: 'options',
                    options: [
                        {
                            name: 'Job',
                            value: 'job',
                        },
                    ],
                    default: 'job',
                    description: 'The resource to operate on.',
                },
                {
                    displayName: 'Operation',
                    name: 'operation',
                    type: 'options',
                    options: [
                        {
                            name: 'Execute',
                            value: 'execute',
                            description: 'Execute a job',
                        },
                        {
                            name: 'Get Metadata',
                            value: 'getMetadata',
                            description: 'Get metadata of a job',
                        },
                    ],
                    default: 'execute',
                    description: 'The operation to perform.',
                },
                {
                    displayName: 'Job Id',
                    name: 'jobid',
                    type: 'string',
                    displayOptions: {
                        show: {
                            operation: [
                                'execute',
                            ],
                            resource: [
                                'job',
                            ],
                        },
                    },
                    default: '',
                    placeholder: 'Rundeck Job Id',
                    required: true,
                    description: 'The job Id to execute.',
                },
                {
                    displayName: 'Arguments',
                    name: 'arguments',
                    placeholder: 'Add Argument',
                    type: 'fixedCollection',
                    typeOptions: {
                        multipleValues: true,
                    },
                    displayOptions: {
                        show: {
                            operation: [
                                'execute',
                            ],
                            resource: [
                                'job',
                            ],
                        },
                    },
                    default: {},
                    options: [
                        {
                            name: 'arguments',
                            displayName: 'Arguments',
                            values: [
                                {
                                    displayName: 'Name',
                                    name: 'name',
                                    type: 'string',
                                    default: '',
                                },
                                {
                                    displayName: 'Value',
                                    name: 'value',
                                    type: 'string',
                                    default: '',
                                },
                            ],
                        },
                    ],
                },
                {
                    displayName: 'Job Id',
                    name: 'jobid',
                    type: 'string',
                    displayOptions: {
                        show: {
                            operation: [
                                'getMetadata',
                            ],
                            resource: [
                                'job',
                            ],
                        },
                    },
                    default: '',
                    placeholder: 'Rundeck Job Id',
                    required: true,
                    description: 'The job Id to get metadata off.',
                },
            ],
        };
    }
    async execute() {
        const items = this.getInputData();
        const returnData = [];
        const length = items.length;
        const operation = this.getNodeParameter('operation', 0);
        const resource = this.getNodeParameter('resource', 0);
        for (let i = 0; i < length; i++) {
            const rundeckApi = new RundeckApi_1.RundeckApi(this);
            if (resource === 'job') {
                if (operation === 'execute') {
                    const jobid = this.getNodeParameter('jobid', i);
                    const rundeckArguments = this.getNodeParameter('arguments', i).arguments;
                    const response = await rundeckApi.executeJob(jobid, rundeckArguments);
                    returnData.push(response);
                }
                else if (operation === 'getMetadata') {
                    const jobid = this.getNodeParameter('jobid', i);
                    const response = await rundeckApi.getJobMetadata(jobid);
                    returnData.push(response);
                }
                else {
                    throw new Error(`The operation "${operation}" is not supported!`);
                }
            }
            else {
                throw new Error(`The resource "${resource}" is not supported!`);
            }
        }
        return [this.helpers.returnJsonArray(returnData)];
    }
}
exports.Rundeck = Rundeck;
//# sourceMappingURL=Rundeck.node.js.map