"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Segment = void 0;
const GenericFunctions_1 = require("./GenericFunctions");
const GroupDescription_1 = require("./GroupDescription");
const IdentifyDescription_1 = require("./IdentifyDescription");
const TrackDescription_1 = require("./TrackDescription");
const uuid = require("uuid/v4");
class Segment {
    constructor() {
        this.description = {
            displayName: 'Segment',
            name: 'segment',
            icon: 'file:segment.png',
            group: ['output'],
            version: 1,
            subtitle: '={{$parameter["operation"] + ":" + $parameter["resource"]}}',
            description: 'Consume Segment API',
            defaults: {
                name: 'Segment',
                color: '#6ebb99',
            },
            inputs: ['main'],
            outputs: ['main'],
            credentials: [
                {
                    name: 'segmentApi',
                    required: true,
                },
            ],
            properties: [
                {
                    displayName: 'Resource',
                    name: 'resource',
                    type: 'options',
                    options: [
                        {
                            name: 'Group',
                            value: 'group',
                            description: 'Group lets you associate an identified user with a group',
                        },
                        {
                            name: 'Identify',
                            value: 'identify',
                            description: 'Identify lets you tie a user to their actions',
                        },
                        {
                            name: 'Track',
                            value: 'track',
                            description: 'Track lets you record events',
                        },
                    ],
                    default: 'identify',
                    description: 'Resource to consume.',
                },
                ...GroupDescription_1.groupOperations,
                ...GroupDescription_1.groupFields,
                ...IdentifyDescription_1.identifyOperations,
                ...TrackDescription_1.trackOperations,
                ...IdentifyDescription_1.identifyFields,
                ...TrackDescription_1.trackFields,
            ],
        };
    }
    async execute() {
        const items = this.getInputData();
        const returnData = [];
        const length = items.length;
        const qs = {};
        let responseData;
        const resource = this.getNodeParameter('resource', 0);
        const operation = this.getNodeParameter('operation', 0);
        for (let i = 0; i < length; i++) {
            if (resource === 'group') {
                if (operation === 'add') {
                    const userId = this.getNodeParameter('userId', i);
                    const groupId = this.getNodeParameter('groupId', i);
                    const traits = this.getNodeParameter('traits', i).traitsUi;
                    const context = this.getNodeParameter('context', i).contextUi;
                    const integrations = this.getNodeParameter('integrations', i).integrationsUi;
                    const body = {
                        groupId,
                        traits: {
                            company: {},
                            address: {},
                        },
                        context: {
                            app: {},
                            campaign: {},
                            device: {},
                        },
                        integrations: {},
                    };
                    if (userId) {
                        body.userId = userId;
                    }
                    else {
                        body.anonymousId = uuid();
                    }
                    if (traits) {
                        if (traits.email) {
                            body.traits.email = traits.email;
                        }
                        if (traits.firstname) {
                            body.traits.firstname = traits.firstname;
                        }
                        if (traits.lastname) {
                            body.traits.lastname = traits.lastname;
                        }
                        if (traits.gender) {
                            body.traits.gender = traits.gender;
                        }
                        if (traits.phone) {
                            body.traits.phone = traits.phone;
                        }
                        if (traits.username) {
                            body.traits.username = traits.username;
                        }
                        if (traits.website) {
                            body.traits.website = traits.website;
                        }
                        if (traits.age) {
                            body.traits.age = traits.age;
                        }
                        if (traits.avatar) {
                            body.traits.avatar = traits.avatar;
                        }
                        if (traits.birthday) {
                            body.traits.birthday = traits.birthday;
                        }
                        if (traits.createdAt) {
                            body.traits.createdAt = traits.createdAt;
                        }
                        if (traits.description) {
                            body.traits.description = traits.description;
                        }
                        if (traits.id) {
                            body.traits.id = traits.id;
                        }
                        if (traits.company) {
                            const company = traits.company.companyUi;
                            if (company) {
                                if (company.id) {
                                    body.traits.company.id = company.id;
                                }
                                if (company.name) {
                                    body.traits.company.name = company.name;
                                }
                                if (company.industry) {
                                    body.traits.company.industry = company.industry;
                                }
                                if (company.employeeCount) {
                                    body.traits.company.employeeCount = company.employeeCount;
                                }
                                if (company.plan) {
                                    body.traits.company.plan = company.plan;
                                }
                            }
                        }
                        if (traits.address) {
                            const address = traits.address.addressUi;
                            if (address) {
                                if (address.street) {
                                    body.traits.address.street = address.street;
                                }
                                if (address.city) {
                                    body.traits.address.city = address.city;
                                }
                                if (address.state) {
                                    body.traits.address.state = address.state;
                                }
                                if (address.postalCode) {
                                    body.traits.address.postalCode = address.postalCode;
                                }
                                if (address.country) {
                                    body.traits.address.country = address.country;
                                }
                            }
                        }
                    }
                    if (context) {
                        if (context.active) {
                            body.context.active = context.active;
                        }
                        if (context.ip) {
                            body.context.ip = context.ip;
                        }
                        if (context.locate) {
                            body.context.locate = context.locate;
                        }
                        if (context.page) {
                            body.context.page = context.page;
                        }
                        if (context.timezone) {
                            body.context.timezone = context.timezone;
                        }
                        if (context.timezone) {
                            body.context.timezone = context.timezone;
                        }
                        if (context.app) {
                            const app = context.app.appUi;
                            if (app) {
                                if (app.name) {
                                    body.context.app.name = app.name;
                                }
                                if (app.version) {
                                    body.context.app.version = app.version;
                                }
                                if (app.build) {
                                    body.context.app.build = app.build;
                                }
                            }
                        }
                        if (context.campaign) {
                            const campaign = context.campaign.campaignUi;
                            if (campaign) {
                                if (campaign.name) {
                                    body.context.campaign.name = campaign.name;
                                }
                                if (campaign.source) {
                                    body.context.campaign.source = campaign.source;
                                }
                                if (campaign.medium) {
                                    body.context.campaign.medium = campaign.medium;
                                }
                                if (campaign.term) {
                                    body.context.campaign.term = campaign.term;
                                }
                                if (campaign.content) {
                                    body.context.campaign.content = campaign.content;
                                }
                            }
                        }
                        if (context.device) {
                            const device = context.device.deviceUi;
                            if (device) {
                                if (device.id) {
                                    body.context.device.id = device.id;
                                }
                                if (device.manufacturer) {
                                    body.context.device.manufacturer = device.manufacturer;
                                }
                                if (device.model) {
                                    body.context.device.model = device.model;
                                }
                                if (device.type) {
                                    body.context.device.type = device.type;
                                }
                                if (device.version) {
                                    body.context.device.version = device.version;
                                }
                            }
                        }
                    }
                    if (integrations) {
                        if (integrations.all) {
                            body.integrations.all = integrations.all;
                        }
                        if (integrations.salesforce) {
                            body.integrations.salesforce = integrations.salesforce;
                        }
                    }
                    responseData = await GenericFunctions_1.segmentApiRequest.call(this, 'POST', '/group', body);
                }
            }
            if (resource === 'identify') {
                if (operation === 'create') {
                    const userId = this.getNodeParameter('userId', i);
                    const traits = this.getNodeParameter('traits', i).traitsUi;
                    const context = this.getNodeParameter('context', i).contextUi;
                    const integrations = this.getNodeParameter('integrations', i).integrationsUi;
                    const body = {
                        traits: {
                            company: {},
                            address: {},
                        },
                        context: {
                            app: {},
                            campaign: {},
                            device: {},
                        },
                        integrations: {},
                    };
                    if (userId) {
                        body.userId = userId;
                    }
                    else {
                        body.anonymousId = uuid();
                    }
                    if (traits) {
                        if (traits.email) {
                            body.traits.email = traits.email;
                        }
                        if (traits.firstname) {
                            body.traits.firstname = traits.firstname;
                        }
                        if (traits.lastname) {
                            body.traits.lastname = traits.lastname;
                        }
                        if (traits.gender) {
                            body.traits.gender = traits.gender;
                        }
                        if (traits.phone) {
                            body.traits.phone = traits.phone;
                        }
                        if (traits.username) {
                            body.traits.username = traits.username;
                        }
                        if (traits.website) {
                            body.traits.website = traits.website;
                        }
                        if (traits.age) {
                            body.traits.age = traits.age;
                        }
                        if (traits.avatar) {
                            body.traits.avatar = traits.avatar;
                        }
                        if (traits.birthday) {
                            body.traits.birthday = traits.birthday;
                        }
                        if (traits.createdAt) {
                            body.traits.createdAt = traits.createdAt;
                        }
                        if (traits.description) {
                            body.traits.description = traits.description;
                        }
                        if (traits.id) {
                            body.traits.id = traits.id;
                        }
                        if (traits.company) {
                            const company = traits.company.companyUi;
                            if (company) {
                                if (company.id) {
                                    body.traits.company.id = company.id;
                                }
                                if (company.name) {
                                    body.traits.company.name = company.name;
                                }
                                if (company.industry) {
                                    body.traits.company.industry = company.industry;
                                }
                                if (company.employeeCount) {
                                    body.traits.company.employeeCount = company.employeeCount;
                                }
                                if (company.plan) {
                                    body.traits.company.plan = company.plan;
                                }
                            }
                        }
                        if (traits.address) {
                            const address = traits.address.addressUi;
                            if (address) {
                                if (address.street) {
                                    body.traits.address.street = address.street;
                                }
                                if (address.city) {
                                    body.traits.address.city = address.city;
                                }
                                if (address.state) {
                                    body.traits.address.state = address.state;
                                }
                                if (address.postalCode) {
                                    body.traits.address.postalCode = address.postalCode;
                                }
                                if (address.country) {
                                    body.traits.address.country = address.country;
                                }
                            }
                        }
                    }
                    if (context) {
                        if (context.active) {
                            body.context.active = context.active;
                        }
                        if (context.ip) {
                            body.context.ip = context.ip;
                        }
                        if (context.locate) {
                            body.context.locate = context.locate;
                        }
                        if (context.page) {
                            body.context.page = context.page;
                        }
                        if (context.timezone) {
                            body.context.timezone = context.timezone;
                        }
                        if (context.timezone) {
                            body.context.timezone = context.timezone;
                        }
                        if (context.app) {
                            const app = context.app.appUi;
                            if (app) {
                                if (app.name) {
                                    body.context.app.name = app.name;
                                }
                                if (app.version) {
                                    body.context.app.version = app.version;
                                }
                                if (app.build) {
                                    body.context.app.build = app.build;
                                }
                            }
                        }
                        if (context.campaign) {
                            const campaign = context.campaign.campaignUi;
                            if (campaign) {
                                if (campaign.name) {
                                    body.context.campaign.name = campaign.name;
                                }
                                if (campaign.source) {
                                    body.context.campaign.source = campaign.source;
                                }
                                if (campaign.medium) {
                                    body.context.campaign.medium = campaign.medium;
                                }
                                if (campaign.term) {
                                    body.context.campaign.term = campaign.term;
                                }
                                if (campaign.content) {
                                    body.context.campaign.content = campaign.content;
                                }
                            }
                        }
                        if (context.device) {
                            const device = context.device.deviceUi;
                            if (device) {
                                if (device.id) {
                                    body.context.device.id = device.id;
                                }
                                if (device.manufacturer) {
                                    body.context.device.manufacturer = device.manufacturer;
                                }
                                if (device.model) {
                                    body.context.device.model = device.model;
                                }
                                if (device.type) {
                                    body.context.device.type = device.type;
                                }
                                if (device.version) {
                                    body.context.device.version = device.version;
                                }
                            }
                        }
                    }
                    if (integrations) {
                        if (integrations.all) {
                            body.integrations.all = integrations.all;
                        }
                        if (integrations.salesforce) {
                            body.integrations.salesforce = integrations.salesforce;
                        }
                    }
                    responseData = await GenericFunctions_1.segmentApiRequest.call(this, 'POST', '/identify', body);
                }
            }
            if (resource === 'track') {
                if (operation === 'event') {
                    const userId = this.getNodeParameter('userId', i);
                    const event = this.getNodeParameter('event', i);
                    const traits = this.getNodeParameter('traits', i).traitsUi;
                    const context = this.getNodeParameter('context', i).contextUi;
                    const integrations = this.getNodeParameter('integrations', i).integrationsUi;
                    const properties = this.getNodeParameter('properties', i).propertiesUi;
                    const body = {
                        event,
                        traits: {
                            company: {},
                            address: {},
                        },
                        context: {
                            app: {},
                            campaign: {},
                            device: {},
                        },
                        integrations: {},
                        properties: {},
                    };
                    if (userId) {
                        body.userId = userId;
                    }
                    else {
                        body.anonymousId = uuid();
                    }
                    if (traits) {
                        if (traits.email) {
                            body.traits.email = traits.email;
                        }
                        if (traits.firstname) {
                            body.traits.firstname = traits.firstname;
                        }
                        if (traits.lastname) {
                            body.traits.lastname = traits.lastname;
                        }
                        if (traits.gender) {
                            body.traits.gender = traits.gender;
                        }
                        if (traits.phone) {
                            body.traits.phone = traits.phone;
                        }
                        if (traits.username) {
                            body.traits.username = traits.username;
                        }
                        if (traits.website) {
                            body.traits.website = traits.website;
                        }
                        if (traits.age) {
                            body.traits.age = traits.age;
                        }
                        if (traits.avatar) {
                            body.traits.avatar = traits.avatar;
                        }
                        if (traits.birthday) {
                            body.traits.birthday = traits.birthday;
                        }
                        if (traits.createdAt) {
                            body.traits.createdAt = traits.createdAt;
                        }
                        if (traits.description) {
                            body.traits.description = traits.description;
                        }
                        if (traits.id) {
                            body.traits.id = traits.id;
                        }
                        if (traits.company) {
                            const company = traits.company.companyUi;
                            if (company) {
                                if (company.id) {
                                    body.traits.company.id = company.id;
                                }
                                if (company.name) {
                                    body.traits.company.name = company.name;
                                }
                                if (company.industry) {
                                    body.traits.company.industry = company.industry;
                                }
                                if (company.employeeCount) {
                                    body.traits.company.employeeCount = company.employeeCount;
                                }
                                if (company.plan) {
                                    body.traits.company.plan = company.plan;
                                }
                            }
                        }
                        if (traits.address) {
                            const address = traits.address.addressUi;
                            if (address) {
                                if (address.street) {
                                    body.traits.address.street = address.street;
                                }
                                if (address.city) {
                                    body.traits.address.city = address.city;
                                }
                                if (address.state) {
                                    body.traits.address.state = address.state;
                                }
                                if (address.postalCode) {
                                    body.traits.address.postalCode = address.postalCode;
                                }
                                if (address.country) {
                                    body.traits.address.country = address.country;
                                }
                            }
                        }
                    }
                    if (context) {
                        if (context.active) {
                            body.context.active = context.active;
                        }
                        if (context.ip) {
                            body.context.ip = context.ip;
                        }
                        if (context.locate) {
                            body.context.locate = context.locate;
                        }
                        if (context.page) {
                            body.context.page = context.page;
                        }
                        if (context.timezone) {
                            body.context.timezone = context.timezone;
                        }
                        if (context.timezone) {
                            body.context.timezone = context.timezone;
                        }
                        if (context.app) {
                            const app = context.app.appUi;
                            if (app) {
                                if (app.name) {
                                    body.context.app.name = app.name;
                                }
                                if (app.version) {
                                    body.context.app.version = app.version;
                                }
                                if (app.build) {
                                    body.context.app.build = app.build;
                                }
                            }
                        }
                        if (context.campaign) {
                            const campaign = context.campaign.campaignUi;
                            if (campaign) {
                                if (campaign.name) {
                                    body.context.campaign.name = campaign.name;
                                }
                                if (campaign.source) {
                                    body.context.campaign.source = campaign.source;
                                }
                                if (campaign.medium) {
                                    body.context.campaign.medium = campaign.medium;
                                }
                                if (campaign.term) {
                                    body.context.campaign.term = campaign.term;
                                }
                                if (campaign.content) {
                                    body.context.campaign.content = campaign.content;
                                }
                            }
                        }
                        if (context.device) {
                            const device = context.device.deviceUi;
                            if (device) {
                                if (device.id) {
                                    body.context.device.id = device.id;
                                }
                                if (device.manufacturer) {
                                    body.context.device.manufacturer = device.manufacturer;
                                }
                                if (device.model) {
                                    body.context.device.model = device.model;
                                }
                                if (device.type) {
                                    body.context.device.type = device.type;
                                }
                                if (device.version) {
                                    body.context.device.version = device.version;
                                }
                            }
                        }
                    }
                    if (integrations) {
                        if (integrations.all) {
                            body.integrations.all = integrations.all;
                        }
                        if (integrations.salesforce) {
                            body.integrations.salesforce = integrations.salesforce;
                        }
                    }
                    if (properties) {
                        if (properties.revenue) {
                            body.properties.revenue = properties.revenue;
                        }
                        if (properties.currency) {
                            body.properties.currency = properties.currency;
                        }
                        if (properties.value) {
                            body.properties.value = properties.value;
                        }
                    }
                    responseData = await GenericFunctions_1.segmentApiRequest.call(this, 'POST', '/track', body);
                }
                if (operation === 'page') {
                    const userId = this.getNodeParameter('userId', i);
                    const event = this.getNodeParameter('event', i);
                    const traits = this.getNodeParameter('traits', i).traitsUi;
                    const context = this.getNodeParameter('context', i).contextUi;
                    const integrations = this.getNodeParameter('integrations', i).integrationsUi;
                    const properties = this.getNodeParameter('properties', i).propertiesUi;
                    const body = {
                        event,
                        traits: {
                            company: {},
                            address: {},
                        },
                        context: {
                            app: {},
                            campaign: {},
                            device: {},
                        },
                        integrations: {},
                        properties: {},
                    };
                    if (userId) {
                        body.userId = userId;
                    }
                    else {
                        body.anonymousId = uuid();
                    }
                    if (traits) {
                        if (traits.email) {
                            body.traits.email = traits.email;
                        }
                        if (traits.firstname) {
                            body.traits.firstname = traits.firstname;
                        }
                        if (traits.lastname) {
                            body.traits.lastname = traits.lastname;
                        }
                        if (traits.gender) {
                            body.traits.gender = traits.gender;
                        }
                        if (traits.phone) {
                            body.traits.phone = traits.phone;
                        }
                        if (traits.username) {
                            body.traits.username = traits.username;
                        }
                        if (traits.website) {
                            body.traits.website = traits.website;
                        }
                        if (traits.age) {
                            body.traits.age = traits.age;
                        }
                        if (traits.avatar) {
                            body.traits.avatar = traits.avatar;
                        }
                        if (traits.birthday) {
                            body.traits.birthday = traits.birthday;
                        }
                        if (traits.createdAt) {
                            body.traits.createdAt = traits.createdAt;
                        }
                        if (traits.description) {
                            body.traits.description = traits.description;
                        }
                        if (traits.id) {
                            body.traits.id = traits.id;
                        }
                        if (traits.company) {
                            const company = traits.company.companyUi;
                            if (company) {
                                if (company.id) {
                                    body.traits.company.id = company.id;
                                }
                                if (company.name) {
                                    body.traits.company.name = company.name;
                                }
                                if (company.industry) {
                                    body.traits.company.industry = company.industry;
                                }
                                if (company.employeeCount) {
                                    body.traits.company.employeeCount = company.employeeCount;
                                }
                                if (company.plan) {
                                    body.traits.company.plan = company.plan;
                                }
                            }
                        }
                        if (traits.address) {
                            const address = traits.address.addressUi;
                            if (address) {
                                if (address.street) {
                                    body.traits.address.street = address.street;
                                }
                                if (address.city) {
                                    body.traits.address.city = address.city;
                                }
                                if (address.state) {
                                    body.traits.address.state = address.state;
                                }
                                if (address.postalCode) {
                                    body.traits.address.postalCode = address.postalCode;
                                }
                                if (address.country) {
                                    body.traits.address.country = address.country;
                                }
                            }
                        }
                    }
                    if (context) {
                        if (context.active) {
                            body.context.active = context.active;
                        }
                        if (context.ip) {
                            body.context.ip = context.ip;
                        }
                        if (context.locate) {
                            body.context.locate = context.locate;
                        }
                        if (context.page) {
                            body.context.page = context.page;
                        }
                        if (context.timezone) {
                            body.context.timezone = context.timezone;
                        }
                        if (context.timezone) {
                            body.context.timezone = context.timezone;
                        }
                        if (context.app) {
                            const app = context.app.appUi;
                            if (app) {
                                if (app.name) {
                                    body.context.app.name = app.name;
                                }
                                if (app.version) {
                                    body.context.app.version = app.version;
                                }
                                if (app.build) {
                                    body.context.app.build = app.build;
                                }
                            }
                        }
                        if (context.campaign) {
                            const campaign = context.campaign.campaignUi;
                            if (campaign) {
                                if (campaign.name) {
                                    body.context.campaign.name = campaign.name;
                                }
                                if (campaign.source) {
                                    body.context.campaign.source = campaign.source;
                                }
                                if (campaign.medium) {
                                    body.context.campaign.medium = campaign.medium;
                                }
                                if (campaign.term) {
                                    body.context.campaign.term = campaign.term;
                                }
                                if (campaign.content) {
                                    body.context.campaign.content = campaign.content;
                                }
                            }
                        }
                        if (context.device) {
                            const device = context.device.deviceUi;
                            if (device) {
                                if (device.id) {
                                    body.context.device.id = device.id;
                                }
                                if (device.manufacturer) {
                                    body.context.device.manufacturer = device.manufacturer;
                                }
                                if (device.model) {
                                    body.context.device.model = device.model;
                                }
                                if (device.type) {
                                    body.context.device.type = device.type;
                                }
                                if (device.version) {
                                    body.context.device.version = device.version;
                                }
                            }
                        }
                    }
                    if (integrations) {
                        if (integrations.all) {
                            body.integrations.all = integrations.all;
                        }
                        if (integrations.salesforce) {
                            body.integrations.salesforce = integrations.salesforce;
                        }
                    }
                    if (properties) {
                        if (properties.name) {
                            body.properties.name = properties.name;
                        }
                        if (properties.path) {
                            body.properties.path = properties.path;
                        }
                        if (properties.referrer) {
                            body.properties.referrer = properties.referrer;
                        }
                        if (properties.search) {
                            body.properties.search = properties.search;
                        }
                        if (properties.title) {
                            body.properties.title = properties.title;
                        }
                        if (properties.url) {
                            body.properties.url = properties.url;
                        }
                        if (properties.keywords) {
                            body.properties.keywords = properties.keywords;
                        }
                    }
                    responseData = await GenericFunctions_1.segmentApiRequest.call(this, 'POST', '/page', body);
                }
            }
            if (Array.isArray(responseData)) {
                returnData.push.apply(returnData, responseData);
            }
            else {
                returnData.push(responseData);
            }
        }
        return [this.helpers.returnJsonArray(returnData)];
    }
}
exports.Segment = Segment;
//# sourceMappingURL=Segment.node.js.map