"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SplitInBatches = void 0;
class SplitInBatches {
    constructor() {
        this.description = {
            displayName: 'Split In Batches',
            name: 'splitInBatches',
            icon: 'fa:th-large',
            group: ['organization'],
            version: 1,
            description: 'Saves the originally incoming data and with each itteration it returns a predefined amount of them.',
            defaults: {
                name: 'SplitInBatches',
                color: '#007755',
            },
            inputs: ['main'],
            outputs: ['main'],
            properties: [
                {
                    displayName: 'Batch Size',
                    name: 'batchSize',
                    type: 'number',
                    typeOptions: {
                        minValue: 1,
                    },
                    default: 10,
                    description: 'The number of items to return with each call.',
                },
                {
                    displayName: 'Options',
                    name: 'options',
                    type: 'collection',
                    placeholder: 'Add Option',
                    default: {},
                    options: [
                        {
                            displayName: 'Reset',
                            name: 'reset',
                            type: 'boolean',
                            default: false,
                            description: 'If set to true, the node will be reset and so with the current input-data newly initialized.',
                        },
                    ],
                },
            ],
        };
    }
    async execute() {
        const items = this.getInputData().slice();
        const nodeContext = this.getContext('node');
        const batchSize = this.getNodeParameter('batchSize', 0);
        const returnItems = [];
        const options = this.getNodeParameter('options', 0, {});
        if (nodeContext.items === undefined || options.reset === true) {
            nodeContext.currentRunIndex = 0;
            nodeContext.maxRunIndex = Math.ceil(items.length / batchSize);
            returnItems.push.apply(returnItems, items.splice(0, batchSize));
            nodeContext.items = items;
        }
        else {
            nodeContext.currentRunIndex += 1;
            returnItems.push.apply(returnItems, nodeContext.items.splice(0, batchSize));
        }
        nodeContext.noItemsLeft = nodeContext.items.length === 0;
        if (returnItems.length === 0) {
            return null;
        }
        return this.prepareOutputData(returnItems);
    }
}
exports.SplitInBatches = SplitInBatches;
//# sourceMappingURL=SplitInBatches.node.js.map