"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.vonageApiRequest = void 0;
async function vonageApiRequest(method, path, body = {}, qs = {}, option = {}) {
    const credentials = this.getCredentials('vonageApi');
    body.api_key = credentials.apiKey;
    body.api_secret = credentials.apiSecret;
    const options = {
        method,
        form: body,
        qs,
        uri: `https://rest.nexmo.com${path}`,
        json: true,
    };
    try {
        if (Object.keys(body).length === 0) {
            delete options.body;
        }
        return await this.helpers.request.call(this, options);
    }
    catch (error) {
        if (error.response && error.response.body && error.response.body.error) {
            let errors = error.response.body.error.errors;
            errors = errors.map((e) => e.message);
            throw new Error(`Vonage error response [${error.statusCode}]: ${errors.join('|')}`);
        }
        throw error;
    }
}
exports.vonageApiRequest = vonageApiRequest;
//# sourceMappingURL=GenericFunctions.js.map