"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.webflowApiRequest = void 0;
async function webflowApiRequest(method, resource, body = {}, qs = {}, uri, option = {}) {
    const authenticationMethod = this.getNodeParameter('authentication', 0);
    let options = {
        headers: {
            'accept-version': '1.0.0',
        },
        method,
        qs,
        body,
        uri: uri || `https://api.webflow.com${resource}`,
        json: true,
    };
    options = Object.assign({}, options, option);
    if (Object.keys(options.body).length === 0) {
        delete options.body;
    }
    try {
        if (authenticationMethod === 'accessToken') {
            const credentials = this.getCredentials('webflowApi');
            if (credentials === undefined) {
                throw new Error('No credentials got returned!');
            }
            options.headers['authorization'] = `Bearer ${credentials.accessToken}`;
            return await this.helpers.request(options);
        }
        else {
            return await this.helpers.requestOAuth2.call(this, 'webflowOAuth2Api', options);
        }
    }
    catch (error) {
        if (error.response.body.err) {
            throw new Error(`Webflow Error: [${error.statusCode}]: ${error.response.body.err}`);
        }
        return error;
    }
}
exports.webflowApiRequest = webflowApiRequest;
//# sourceMappingURL=GenericFunctions.js.map