"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WriteBinaryFile = void 0;
const n8n_core_1 = require("n8n-core");
const fs_1 = require("fs");
const util_1 = require("util");
const fsWriteFileAsync = util_1.promisify(fs_1.writeFile);
class WriteBinaryFile {
    constructor() {
        this.description = {
            displayName: 'Write Binary File',
            name: 'writeBinaryFile',
            icon: 'fa:file-export',
            group: ['output'],
            version: 1,
            description: 'Writes a binary file to disk',
            defaults: {
                name: 'Write Binary File',
                color: '#CC2233',
            },
            inputs: ['main'],
            outputs: ['main'],
            properties: [
                {
                    displayName: 'File Name',
                    name: 'fileName',
                    type: 'string',
                    default: '',
                    required: true,
                    placeholder: '/data/example.jpg',
                    description: 'Path to which the file should be written.',
                },
                {
                    displayName: 'Property Name',
                    name: 'dataPropertyName',
                    type: 'string',
                    default: 'data',
                    required: true,
                    description: 'Name of the binary property which contains<br />the data for the file to be written.',
                },
            ],
        };
    }
    async executeSingle() {
        const item = this.getInputData();
        const dataPropertyName = this.getNodeParameter('dataPropertyName');
        const fileName = this.getNodeParameter('fileName');
        if (item.binary === undefined) {
            throw new Error('No binary data set. So file can not be written!');
        }
        if (item.binary[dataPropertyName] === undefined) {
            throw new Error(`The binary property "${dataPropertyName}" does not exist. So no file can be written!`);
        }
        await fsWriteFileAsync(fileName, Buffer.from(item.binary[dataPropertyName].data, n8n_core_1.BINARY_ENCODING), 'binary');
        const newItem = {
            json: {},
        };
        Object.assign(newItem.json, item.json);
        if (item.binary !== undefined) {
            newItem.binary = {};
            Object.assign(newItem.binary, item.binary);
        }
        newItem.json.fileName = fileName;
        return newItem;
    }
}
exports.WriteBinaryFile = WriteBinaryFile;
//# sourceMappingURL=WriteBinaryFile.node.js.map