"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.zohoApiRequestAllItems = exports.zohoApiRequest = void 0;
async function zohoApiRequest(method, resource, body = {}, qs = {}, uri, option = {}) {
    const options = {
        headers: {
            'Content-Type': 'application/json',
        },
        method,
        body: {
            data: [
                body,
            ],
        },
        qs,
        uri: uri || `https://www.zohoapis.com/crm/v2${resource}`,
        json: true,
    };
    try {
        return await this.helpers.requestOAuth2.call(this, 'zohoOAuth2Api', options);
    }
    catch (error) {
        if (error.response && error.response.body && error.response.body.message) {
            throw new Error(`Zoho error response [${error.statusCode}]: ${error.response.body.message}`);
        }
        throw error;
    }
}
exports.zohoApiRequest = zohoApiRequest;
async function zohoApiRequestAllItems(propertyName, method, endpoint, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    let uri;
    query.per_page = 200;
    query.page = 0;
    do {
        responseData = await zohoApiRequest.call(this, method, endpoint, body, query, uri);
        uri = responseData.info.more_records;
        returnData.push.apply(returnData, responseData[propertyName]);
        query.page++;
    } while (responseData.info.more_records !== undefined &&
        responseData.info.more_records === true);
    return returnData;
}
exports.zohoApiRequestAllItems = zohoApiRequestAllItems;
//# sourceMappingURL=GenericFunctions.js.map