"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ZohoCrm = void 0;
const GenericFunctions_1 = require("./GenericFunctions");
const LeadDescription_1 = require("./LeadDescription");
class ZohoCrm {
    constructor() {
        this.description = {
            displayName: 'Zoho CRM',
            name: 'zohoCrm',
            icon: 'file:zohoCrm.png',
            subtitle: '={{$parameter["operation"] + ": " + $parameter["resource"]}}',
            group: ['input'],
            version: 1,
            description: 'Consume Zoho CRM API.',
            defaults: {
                name: 'Zoho CRM',
                color: '#CE2232',
            },
            inputs: ['main'],
            outputs: ['main'],
            credentials: [
                {
                    name: 'zohoOAuth2Api',
                    required: true,
                },
            ],
            properties: [
                {
                    displayName: 'Resource',
                    name: 'resource',
                    type: 'options',
                    options: [
                        {
                            name: 'Lead',
                            value: 'lead',
                        },
                    ],
                    default: 'lead',
                    description: 'The resource to operate on.',
                },
                ...LeadDescription_1.leadOperations,
                ...LeadDescription_1.leadFields,
            ],
        };
        this.methods = {
            loadOptions: {
                async getUsers() {
                    const returnData = [];
                    const { users } = await GenericFunctions_1.zohoApiRequest.call(this, 'GET', '/users', {}, { type: 'AllUsers' });
                    for (const user of users) {
                        const userName = `${user.first_name} ${user.last_name}`;
                        const userId = user.profile.id;
                        returnData.push({
                            name: userName,
                            value: userId,
                        });
                    }
                    return returnData;
                },
                async getAccounts() {
                    const returnData = [];
                    const qs = {};
                    qs.sort_by = 'Created_Time';
                    qs.sort_order = 'desc';
                    const { data } = await GenericFunctions_1.zohoApiRequest.call(this, 'GET', '/accounts', {}, qs);
                    for (const account of data) {
                        const accountName = account.Account_Name;
                        const accountId = account.id;
                        returnData.push({
                            name: accountName,
                            value: accountId,
                        });
                    }
                    return returnData;
                },
                async getLeadStatuses() {
                    const returnData = [];
                    const qs = {};
                    qs.module = 'leads';
                    const { fields } = await GenericFunctions_1.zohoApiRequest.call(this, 'GET', '/settings/fields', {}, qs);
                    for (const field of fields) {
                        if (field.api_name === 'Lead_Status') {
                            for (const value of field.pick_list_values) {
                                const valueName = value.display_value;
                                const valueId = value.actual_value;
                                returnData.push({
                                    name: valueName,
                                    value: valueId,
                                });
                                return returnData;
                            }
                        }
                    }
                    return returnData;
                },
                async getLeadSources() {
                    const returnData = [];
                    const qs = {};
                    qs.module = 'leads';
                    const { fields } = await GenericFunctions_1.zohoApiRequest.call(this, 'GET', '/settings/fields', {}, qs);
                    for (const field of fields) {
                        if (field.api_name === 'Lead_Source') {
                            for (const value of field.pick_list_values) {
                                const valueName = value.display_value;
                                const valueId = value.actual_value;
                                returnData.push({
                                    name: valueName,
                                    value: valueId,
                                });
                                return returnData;
                            }
                        }
                    }
                    return returnData;
                },
                async getIndustries() {
                    const returnData = [];
                    const qs = {};
                    qs.module = 'leads';
                    const { fields } = await GenericFunctions_1.zohoApiRequest.call(this, 'GET', '/settings/fields', {}, qs);
                    for (const field of fields) {
                        if (field.api_name === 'Industry') {
                            for (const value of field.pick_list_values) {
                                const valueName = value.display_value;
                                const valueId = value.actual_value;
                                returnData.push({
                                    name: valueName,
                                    value: valueId,
                                });
                                return returnData;
                            }
                        }
                    }
                    return returnData;
                },
                async getLeadFields() {
                    const returnData = [];
                    const qs = {};
                    qs.module = 'leads';
                    const { fields } = await GenericFunctions_1.zohoApiRequest.call(this, 'GET', '/settings/fields', {}, qs);
                    for (const field of fields) {
                        returnData.push({
                            name: field.field_label,
                            value: field.api_name,
                        });
                    }
                    return returnData;
                },
            },
        };
    }
    async execute() {
        const items = this.getInputData();
        const returnData = [];
        const length = items.length;
        const qs = {};
        let responseData;
        for (let i = 0; i < length; i++) {
            const resource = this.getNodeParameter('resource', 0);
            const operation = this.getNodeParameter('operation', 0);
            if (resource === 'lead') {
                if (operation === 'create') {
                    const lastName = this.getNodeParameter('lastName', i);
                    const additionalFields = this.getNodeParameter('additionalFields', i);
                    const body = {
                        Last_Name: lastName,
                    };
                    if (additionalFields.owner) {
                        body.Lead_Owner = additionalFields.owner;
                    }
                    if (additionalFields.company) {
                        body.Company = additionalFields.company;
                    }
                    if (additionalFields.firstName) {
                        body.First_Name = additionalFields.firstName;
                    }
                    if (additionalFields.email) {
                        body.Email = additionalFields.email;
                    }
                    if (additionalFields.title) {
                        body.Designation = additionalFields.title;
                    }
                    if (additionalFields.phone) {
                        body.Phone = additionalFields.phone;
                    }
                    if (additionalFields.mobile) {
                        body.Mobile = additionalFields.mobile;
                    }
                    if (additionalFields.leadStatus) {
                        body.Lead_Status = additionalFields.leadStatus;
                    }
                    if (additionalFields.fax) {
                        body.Fax = additionalFields.fax;
                    }
                    if (additionalFields.website) {
                        body.Website = additionalFields.website;
                    }
                    if (additionalFields.leadSource) {
                        body.Lead_Source = additionalFields.leadSource;
                    }
                    if (additionalFields.industry) {
                        body.Industry = additionalFields.industry;
                    }
                    if (additionalFields.numberOfEmployees) {
                        body.No_of_Employees = additionalFields.numberOfEmployees;
                    }
                    if (additionalFields.annualRevenue) {
                        body.Annual_Revenue = additionalFields.annualRevenue;
                    }
                    if (additionalFields.emailOptOut) {
                        body.Email_Opt_Out = additionalFields.emailOptOut;
                    }
                    if (additionalFields.skypeId) {
                        body.Skype_ID = additionalFields.skypeId;
                    }
                    if (additionalFields.salutation) {
                        body.Salutation = additionalFields.salutation;
                    }
                    if (additionalFields.secondaryEmail) {
                        body.Secondary_Email = additionalFields.secondaryEmail;
                    }
                    if (additionalFields.twitter) {
                        body.Twitter = additionalFields.twitter;
                    }
                    if (additionalFields.isRecordDuplicate) {
                        body.Is_Record_Duplicate = additionalFields.isRecordDuplicate;
                    }
                    if (additionalFields.description) {
                        body.Description = additionalFields.description;
                    }
                    const address = this.getNodeParameter('addressUi', i).addressValues;
                    if (address) {
                        if (address.country) {
                            body.Country = address.country;
                        }
                        if (address.city) {
                            body.City = address.city;
                        }
                        if (address.state) {
                            body.State = address.state;
                        }
                        if (address.street) {
                            body.Street = address.street;
                        }
                        if (address.zipCode) {
                            body.Zip_Code = address.zipCode;
                        }
                    }
                    responseData = await GenericFunctions_1.zohoApiRequest.call(this, 'POST', '/leads', body);
                    responseData = responseData.data;
                    if (responseData.length) {
                        responseData = responseData[0].details;
                    }
                }
                if (operation === 'update') {
                    const leadId = this.getNodeParameter('leadId', i);
                    const additionalFields = this.getNodeParameter('additionalFields', i);
                    const body = {};
                    if (additionalFields.lastName) {
                        body.Last_Name = additionalFields.lastName;
                    }
                    if (additionalFields.owner) {
                        body.Lead_Owner = additionalFields.owner;
                    }
                    if (additionalFields.company) {
                        body.Company = additionalFields.company;
                    }
                    if (additionalFields.firstName) {
                        body.First_Name = additionalFields.firstName;
                    }
                    if (additionalFields.email) {
                        body.Email = additionalFields.email;
                    }
                    if (additionalFields.title) {
                        body.Designation = additionalFields.title;
                    }
                    if (additionalFields.phone) {
                        body.Phone = additionalFields.phone;
                    }
                    if (additionalFields.mobile) {
                        body.Mobile = additionalFields.mobile;
                    }
                    if (additionalFields.leadStatus) {
                        body.Lead_Status = additionalFields.leadStatus;
                    }
                    if (additionalFields.fax) {
                        body.Fax = additionalFields.fax;
                    }
                    if (additionalFields.website) {
                        body.Website = additionalFields.website;
                    }
                    if (additionalFields.leadSource) {
                        body.Lead_Source = additionalFields.leadSource;
                    }
                    if (additionalFields.industry) {
                        body.Industry = additionalFields.industry;
                    }
                    if (additionalFields.numberOfEmployees) {
                        body.No_of_Employees = additionalFields.numberOfEmployees;
                    }
                    if (additionalFields.annualRevenue) {
                        body.Annual_Revenue = additionalFields.annualRevenue;
                    }
                    if (additionalFields.emailOptOut) {
                        body.Email_Opt_Out = additionalFields.emailOptOut;
                    }
                    if (additionalFields.skypeId) {
                        body.Skype_ID = additionalFields.skypeId;
                    }
                    if (additionalFields.salutation) {
                        body.Salutation = additionalFields.salutation;
                    }
                    if (additionalFields.secondaryEmail) {
                        body.Secondary_Email = additionalFields.secondaryEmail;
                    }
                    if (additionalFields.twitter) {
                        body.Twitter = additionalFields.twitter;
                    }
                    if (additionalFields.isRecordDuplicate) {
                        body.Is_Record_Duplicate = additionalFields.isRecordDuplicate;
                    }
                    if (additionalFields.description) {
                        body.Description = additionalFields.description;
                    }
                    const address = this.getNodeParameter('addressUi', i).addressValues;
                    if (address) {
                        if (address.country) {
                            body.Country = address.country;
                        }
                        if (address.city) {
                            body.City = address.city;
                        }
                        if (address.state) {
                            body.State = address.state;
                        }
                        if (address.street) {
                            body.Street = address.street;
                        }
                        if (address.zipCode) {
                            body.Zip_Code = address.zipCode;
                        }
                    }
                    responseData = await GenericFunctions_1.zohoApiRequest.call(this, 'PUT', `/leads/${leadId}`, body);
                    responseData = responseData.data;
                    if (responseData.length) {
                        responseData = responseData[0].details;
                    }
                }
                if (operation === 'get') {
                    const leadId = this.getNodeParameter('leadId', i);
                    responseData = await GenericFunctions_1.zohoApiRequest.call(this, 'GET', `/leads/${leadId}`);
                    if (responseData !== undefined) {
                        responseData = responseData.data;
                    }
                }
                if (operation === 'getAll') {
                    const returnAll = this.getNodeParameter('returnAll', i);
                    const options = this.getNodeParameter('options', i);
                    if (options.fields) {
                        qs.fields = options.fields.join(',');
                    }
                    if (options.approved) {
                        qs.approved = options.approved;
                    }
                    if (options.converted) {
                        qs.converted = options.converted;
                    }
                    if (options.includeChild) {
                        qs.include_child = options.includeChild;
                    }
                    if (options.sortOrder) {
                        qs.sort_order = options.sortOrder;
                    }
                    if (options.sortBy) {
                        qs.sort_by = options.sortBy;
                    }
                    if (options.territoryId) {
                        qs.territory_id = options.territoryId;
                    }
                    if (returnAll) {
                        responseData = await GenericFunctions_1.zohoApiRequestAllItems.call(this, 'data', 'GET', '/leads', {}, qs);
                    }
                    else {
                        qs.per_page = this.getNodeParameter('limit', i);
                        responseData = await GenericFunctions_1.zohoApiRequest.call(this, 'GET', '/leads', {}, qs);
                        responseData = responseData.data;
                    }
                }
                if (operation === 'delete') {
                    const leadId = this.getNodeParameter('leadId', i);
                    responseData = await GenericFunctions_1.zohoApiRequest.call(this, 'DELETE', `/leads/${leadId}`);
                    responseData = responseData.data;
                }
                if (operation === 'getFields') {
                    qs.module = 'leads';
                    responseData = await GenericFunctions_1.zohoApiRequest.call(this, 'GET', '/settings/fields', {}, qs);
                    responseData = responseData.fields;
                }
            }
            if (Array.isArray(responseData)) {
                returnData.push.apply(returnData, responseData);
            }
            else if (responseData !== undefined) {
                returnData.push(responseData);
            }
        }
        return [this.helpers.returnJsonArray(returnData)];
    }
}
exports.ZohoCrm = ZohoCrm;
//# sourceMappingURL=ZohoCrm.node.js.map